/*
TECNISA - TECNOLOGIA EM INFORMTICA

NOME: APURAC_GESLASER

DESCRIO:
   PROCEDIMENTO PARA APURAO DE FATURAMENTO DE CLIENTES EM FILIAIS
   QUE UTILIZAM O TIPO DE CONTRATO GESTO LASER.

CRIAO:
04/10/04 - CRISTIANE FARIA DOS SANTOS

@c:\WEB_411\SQL\END_CONV\ORACLE\6212_FAISTPO_APURAC_GESLASER.SQL

*/

CREATE OR REPLACE PROCEDURE NUMERO_CDRS(
   P_CONTADOR    IN  NOVOCODIGO.CDCONTADOR%TYPE,
   P_SEQUENCIAL  OUT NOVOCODIGO.NRSEQUENCIAL%TYPE,
   P_QTDE        IN  NUMBER DEFAULT 1)

AS
   V_COUNT NUMBER;
   V_CODIGO VARCHAR2(10);

BEGIN
   SELECT COUNT(CDCONTADOR) INTO V_COUNT
   FROM NOVOCODIGO
   WHERE CDCONTADOR = P_CONTADOR;

   IF V_COUNT > 0 THEN
      SELECT NRSEQUENCIAL
      INTO   V_CODIGO
      FROM   NOVOCODIGO
      WHERE  CDCONTADOR = P_CONTADOR
      FOR UPDATE;

      UPDATE NOVOCODIGO
      SET NRSEQUENCIAL = LPAD(RTRIM(TO_CHAR(TO_NUMBER(RTRIM(NRSEQUENCIAL)) + P_QTDE)),10,'0')
      WHERE CDCONTADOR = P_CONTADOR;
   ELSE
      V_CODIGO := LPAD(RTRIM(TO_CHAR(0)),10,'0');

      INSERT INTO NOVOCODIGO (CDCONTADOR, NRSEQUENCIAL)
      VALUES (P_CONTADOR, LPAD(RTRIM(TO_CHAR(P_QTDE)),10,'0'));
   END IF;

   P_SEQUENCIAL := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_CODIGO) + 1)),10,'0');

  COMMIT;
END;
/

CREATE OR REPLACE PROCEDURE APURAC_GESLASER (
      P_CDFILIAL    IN FILIAL.CDFILIAL%TYPE,
      P_CDCLIENTE   IN CLIENTE.CDCLIENTE%TYPE,
      P_DATAINI     IN DATE,
      P_DATAFIM     IN DATE,
      P_NRAPURACFAT IN NOTAFISCAL.NRAPURACFAT%TYPE,
      P_IDGERANOTA  IN VARCHAR DEFAULT 'S')
AS

   /* VARIVEIS PARA CONTROLE DE PARAMETROS */
   STIDUTEFEPLA   VARCHAR2(01);

   /* VARIVEIS QUE CONTERO O CURSOR E O REGISTRO */

   V_CDFILIAPUR  CTRLAPURFAT.CDFILIAPUR%TYPE;

   /* VARIAVEIS PARA CONTROLE DE GRAVACAO DA NOTA FISCAL */

   V_CDSERIE      SERIENF.CDSERIE%TYPE;
   V_TTITENSNF    NUMBER;
   V_CONTITEM     NUMBER;
   V_NRLANCTONF   VARCHAR2(20);
   V_NRSEQITPROD  VARCHAR2(04);
   V_CDEMPRESA    FILIAL.CDEMPRESA%TYPE;
   V_CDINSCMUNI   FILIAL.CDINSCMUNI%TYPE;
   V_CDINSCESTA   FILIAL.CDINSCESTA%TYPE;
   V_IDTPIJURCLIE CLIENTE.IDTPIJURCLIE%TYPE;
   V_NRINSJURCLIE CLIENTE.NRINSJURCLIE%TYPE;
   V_IDNOVANOTA   VARCHAR2(01);
   V_VRNOTAFISC   NUMBER;
   V_PRXLANCESTQ  VARCHAR2(10);
   V_VRCREDIDEBI  NOTAFISCAL.VRNOTAFISC%TYPE;

   V_DSAJUCTREC  AJCTRECEBER.DSAJUSTEREC%TYPE;
   V_ENCARGO     ENCARGO.CDENCARGO%TYPE;

   V_CDGRUPOFISC  VARCHAR2(03);
   V_DESCDOTACAO  VARCHAR2(01);
   V_CDAJUSTPADR  VARCHAR2(02);
   V_CDENCREDITO  VARCHAR2(02);
   V_CDENCDEBITO  VARCHAR2(02);

   V_NRGRUPANTE   VARCHAR2(02);
   V_NRAGRUPNF    VARCHAR2(03);
   V_MDNRAGRUP    VARCHAR2(01);
   V_NUMECDRS     VARCHAR2(10);

   V_EXISTE       FLOAT;

   V_CONT         NUMBER;
   V_NRQUINZENA   NUMBER;

   P_DATA         DATE;
   V_SOMAQT       FLOAT;
   V_IDGERAREL    VARCHAR2(01);
BEGIN

   V_VRCREDIDEBI := 0;

   /* FILIAL QUE EST SENDO APURADA (P_FILIAL = FILIPROC)*/
   SELECT MAX(CDFILIAPUR)
   INTO V_CDFILIAPUR
   FROM CTRLAPURFAT
   WHERE CDFILIAL    = P_CDFILIAL AND
         NRAPURACFAT = P_NRAPURACFAT;

   /* BUSCA AS INFORMAOES PARA CADASTRAMENTO DA NOTA FISCAL
      que so as informaes cadastradas para a filial de apurao*/
   SELECT MAX(CDEMPRESA), MAX(CDINSCMUNI), MAX(CDINSCESTA), MAX(CDSERIE)
   INTO V_CDEMPRESA, V_CDINSCMUNI, V_CDINSCESTA, V_CDSERIE
   FROM FILIAL
   WHERE CDFILIAL = V_CDFILIAPUR;

   /* BUSCA AS INFORMAOES PARA CADASTRAMENTO DE AJUSTE  esta informao ser usada se o parametro
      de desconto dotao estiver marcado como no boleto*/
   SELECT MAX(SUBSTR(DSAJUCTREC,1,20))
   INTO V_DSAJUCTREC
   FROM TIPOAJRECEBER
   WHERE V_CDAJUSTPADR = CDAJUCTREC;


   /* APAGA OS REGISTROS DA TRAB_APURAC_GD DE APURACOES ANTERIORES */
   DELETE FROM TRAB_APURAC_GD
   WHERE CDFILIALAPGD  = P_CDFILIAL    AND
         NRAPURACGD    = P_NRAPURACFAT AND
         CDCLIENTEAPGD = P_CDCLIENTE;

   DELETE FROM NFRELACCDRS
   WHERE CDFILIAL    = P_CDFILIAL    AND
         NRAPURACFAT = P_NRAPURACFAT AND
         CDCLIENTE   = P_CDCLIENTE;

 /* PARAMETROS DA FILIAL DE APURAO DA TELA PARAMETROS POR TIPO DE FATURAMENTO*/
   SELECT MAX(SUBSTR(DSPARAMFATFI,15,1)),          /*UTILIZA EFETIVOS DO PLANEJAMENTO (S - sim , N- nao)*/
          MAX(SUBSTR(DSPARAMFATFI,56,1)),          /*DESCONTO DE DOTAO (1-na nota fiscal, 2-no boleto bancario) */
          MAX(SUBSTR(DSPARAMFATFI,57,2)),          /*AJUSTE PADRAO*/
          MAX(SUBSTR(DSPARAMFATFI,59,2)),          /*ENCARGO CREDITO*/
          MAX(SUBSTR(DSPARAMFATFI,61,2))           /*ENCARGO DEBITO*/
   INTO STIDUTEFEPLA, V_DESCDOTACAO, V_CDAJUSTPADR,
        V_CDENCREDITO, V_CDENCDEBITO
   FROM PARAMFILIAL
   WHERE CDFILIAL = V_CDFILIAPUR;

   IF (STIDUTEFEPLA IS NULL) OR (STIDUTEFEPLA = ' ') THEN
      STIDUTEFEPLA := 'N';     /* O DEFAULT E NAO UTILIZAR EFETIVOS DO PLANEJAMENTO */
      -- NAO UTILIZA EFETIVOS DO PLANEJAMENTO
   END IF;

  /* BUSCA O VALOR TOTAL DAS NFS DE SAIDA DO TIPO 12 (CREDITO/DEBITO) DO PERIODO APURADO*/
   SELECT SUM(VRNOTAFISC)
   INTO V_VRCREDIDEBI
   FROM NOTAFISCAL N
   WHERE (N.CDFILIAL     = V_CDFILIAPUR)                  AND
         (N.CDTIPOOPER   = '12')                          AND
         (N.IDENTRSAIDOP = 'S')                           AND
         (N.DTENTRSAID BETWEEN P_DATAINI AND P_DATAFIM);

   IF V_VRCREDIDEBI < 0 THEN
      /* SE FOREM NF DE DEBITO E PREENCHIDO O ENCARGO PARA DEBITO*/
      V_VRCREDIDEBI := V_VRCREDIDEBI * (-1);
      V_ENCARGO    := V_CDENCDEBITO;
   ELSIF V_VRCREDIDEBI > 0 THEN
      /* SE FOREM NF DE CREDITO E PREENCHIDO O ENCARGO PARA CREDITO*/
      V_ENCARGO    :=  V_CDENCREDITO;
   END IF;


   /* EFETUA O CADASTRAMENTO DO SERVICOS NA TABELA DE NOTA E ITENS */
   IF NVL(P_IDGERANOTA,'S') <> 'N' THEN

   /* NUMERO MAXIMO DE ITENS POR NOTA*/
      SELECT NVL(MAX(NRMAXITNF),10)
      INTO V_TTITENSNF
      FROM SERIENF
      WHERE CDEMPRESA  = V_CDEMPRESA  AND
            CDINSCESTA = V_CDINSCESTA AND
            CDSERIE    = V_CDSERIE;

   /* DADOS DO CLIENTE APURADO*/
      SELECT MAX(IDTPIJURCLIE), MAX(NRINSJURCLIE)
      INTO V_IDTPIJURCLIE, V_NRINSJURCLIE
      FROM CLIENTE
      WHERE CDCLIENTE = P_CDCLIENTE;

      /* APAGA TODAS AS NOTAS FISCAIS APURADAS ANTERIORMENTE COM MESMO
         NUMERO DE APURACAO */
      FOR CURS_NF IN (SELECT CDFILIAL, NRLANCTONF
                      FROM NOTAFISCAL
                      WHERE (CDFILIAL    = P_CDFILIAL) AND
                            (NRAPURACFAT = P_NRAPURACFAT)) LOOP
         DELETE FROM RELAT_CDRS
         WHERE CDFILIAL =   CURS_NF.CDFILIAL AND
               NRLANCTONF = CURS_NF.NRLANCTONF;

         DELETA_NF(CURS_NF.CDFILIAL, CURS_NF.NRLANCTONF);

      END LOOP;

      IF STIDUTEFEPLA = 'S' THEN   /* SE UTILIZA EFETIVOS DO PLA*/
           /* APAGA TODAS AS RELAOES ENTRE EFETIVO DO PLA E APURAO NO PERIODO APURADO*/
         UPDATE EFETCLIE
         SET CDFILIFATU  = NULL,
             NRAPURACFAT = NULL
         WHERE CDFILIAL    = V_CDFILIAPUR AND
               CDCLIENTE   = P_CDCLIENTE  AND
               DTEFETCLIE >= P_DATAINI;
      END IF;

      /* APAGA TODAS AS RELAOES ENTRE EFETIVO DO FAI E APURAO NO PERIODO APURADO*/
      UPDATE EFECLIFAT
      SET CDFILIFATU  = NULL,
          NRAPURACFAT = NULL
      WHERE CDFILIAL   = V_CDFILIAPUR AND
            CDCLIENTE  = P_CDCLIENTE  AND
            DTFATURAM >= P_DATAINI;

      /* INICIALIZA OS EFETIVOS  RATEADOS QUE SERAO APURADOS NO CDRS COM AGRUPAMENTO 000*/
      UPDATE EFETRATCDRS
      SET NRAGREFRAT = '000'
      WHERE CDFILIAL = V_CDFILIAPUR AND
            CDCLIENTE = P_CDCLIENTE AND
            DTRATCDRS BETWEEN P_DATAINI AND P_DATAFIM AND
            NRAGREFRAT IS NULL;

      /* INICIALIZA OS EFETIVOS QUE SERAO APURADOS NO CDRS COM AGRUPAMENTO 000*/
      UPDATE EFETCDRS
      SET NRAGRUEFET = '000'
      WHERE CDFILIAL = V_CDFILIAPUR AND
            CDCLIENTE = P_CDCLIENTE AND
            DTEFETCDRS BETWEEN P_DATAINI AND P_DATAFIM AND
            NRAGRUEFET IS NULL;

      FOR C_EFETCDRS IN (SELECT DISTINCT NRAGRUEFET
                         FROM EFETCDRS
                         WHERE
                           (CDFILIAL   = V_CDFILIAPUR)   AND
                           (CDCLIENTE  = P_CDCLIENTE)    AND
                           (DTEFETCDRS BETWEEN P_DATAINI  AND P_DATAFIM)
                         ORDER BY NRAGRUEFET ) LOOP

         V_MDNRAGRUP := 'S';

         FOR C_EFETAGRUP IN (SELECT DISTINCT CDSERVFILI, CDFILIAL, CDCLIENTE, NRAGRUEFET
                             FROM EFETCDRS
                             WHERE
                               (CDFILIAL   = V_CDFILIAPUR)   AND
                               (CDCLIENTE  = P_CDCLIENTE)    AND
                               (NRAGRUEFET = C_EFETCDRS.NRAGRUEFET) AND
                               (DTEFETCDRS BETWEEN P_DATAINI  AND P_DATAFIM)
                             ORDER BY CDSERVFILI) LOOP

            FOR C_EFETRATCDRS IN (SELECT MAX(CDFILIAL) AS CDFILIAL, CDSERVFILI, MAX(CDCLIENTE) AS CDCLIENTE,
                                         VRPRECRATE AS VRPRECUNIT, MAX(CDPRODUTO) AS CDPRODUTO, DTRATCDRS, NRAGREFRAT, SUM(QTDERATEIO) AS QTDERATEIO
                                  FROM EFETRATCDRS
                                  WHERE
                                     (CDFILIAL   = C_EFETAGRUP.CDFILIAL)           AND
                                     (CDCLIENTE  = P_CDCLIENTE)                   AND
                                     (DTRATCDRS BETWEEN P_DATAINI AND P_DATAFIM)  AND
                                     (NRAGREFRAT = C_EFETAGRUP.NRAGRUEFET)
                                  GROUP BY CDSERVFILI, NRAGREFRAT, DTRATCDRS, VRPRECRATE) LOOP

               IF TO_NUMBER(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD')) <= 15 THEN
                  V_NRQUINZENA := 1;
                  P_DATA := TO_DATE('01/'||TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'MM')||'/'||TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'YYYY'),'DD/MM/YYYY');
               ELSE
                  V_NRQUINZENA := 2;
                  P_DATA := TO_DATE('16/'||TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'MM')||'/'||TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'YYYY'),'DD/MM/YYYY');
               END IF;

               SELECT MAX(NRAGRUPNF), MAX(NRCDRS)
               INTO V_NRAGRUPNF, V_NUMECDRS
               FROM RELAT_CDRS
               WHERE CDFILIAL = C_EFETRATCDRS.CDFILIAL     AND
                     CDCLIENTE = C_EFETRATCDRS.CDCLIENTE   AND
                     CDSERVFILI= C_EFETRATCDRS.CDSERVFILI  AND
                     DTINIAPLASER BETWEEN P_DATAINI AND P_DATAFIM AND
                     DTCDRS =  P_DATA                      AND
                     NRQUINZENA = V_NRQUINZENA             AND
                     NRAGRUPNF  = C_EFETCDRS.NRAGRUEFET     AND
                     NRAGRUPRAT  = C_EFETRATCDRS.NRAGREFRAT;

               SELECT COUNT(*)
               INTO V_CONT
               FROM RELAT_CDRS
               WHERE CDFILIAL = C_EFETRATCDRS.CDFILIAL     AND
                     CDCLIENTE = C_EFETRATCDRS.CDCLIENTE   AND
                     DTINIAPLASER BETWEEN P_DATAINI AND P_DATAFIM AND
                     DTCDRS =  P_DATA                      AND
                     NRQUINZENA = V_NRQUINZENA             AND
                     NRAGRUPNF  = C_EFETCDRS.NRAGRUEFET     AND
                     NRAGRUPRAT  = C_EFETRATCDRS.NRAGREFRAT;

               IF NOT V_NRAGRUPNF IS NULL THEN
                  IF V_CONT = 13 THEN

                     NUMERO_CDRS('NUMECDRS'||C_EFETRATCDRS.CDFILIAL||C_EFETRATCDRS.CDCLIENTE,V_NUMECDRS);

                     SELECT COUNT(*)
                     INTO V_EXISTE
                     FROM RELAT_CDRS
                     WHERE CDFILIAL = C_EFETRATCDRS.CDFILIAL     AND
                            CDCLIENTE = C_EFETRATCDRS.CDCLIENTE   AND
                            NRCDRS = V_NUMECDRS;

                     IF V_EXISTE > 0 THEN
                        WHILE V_EXISTE > 0 LOOP
                           V_NUMECDRS := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_NUMECDRS) + 1)),10,'0');

                           SELECT COUNT(*)
                           INTO V_EXISTE
                           FROM RELAT_CDRS
                           WHERE CDFILIAL = C_EFETRATCDRS.CDFILIAL     AND
                                 CDCLIENTE = C_EFETRATCDRS.CDCLIENTE   AND
                                 NRCDRS = V_NUMECDRS;
                        END LOOP;

                        UPDATE NOVOCODIGO
                        SET NRSEQUENCIAL = V_NUMECDRS
                        WHERE CDCONTADOR = 'NUMECDRS'||C_EFETRATCDRS.CDFILIAL||C_EFETRATCDRS.CDCLIENTE;

                     END IF;

                     INSERT INTO RELAT_CDRS
                     (CDFILIAL, NRCDRS, CDCLIENTE,
                      CDSERVFILI, DTCDRS, NRQUINZENA,
                      QTEFETIVOS01,QTEFETIVOS02,QTEFETIVOS03,QTEFETIVOS04,QTEFETIVOS05,QTEFETIVOS06,QTEFETIVOS07,
                      QTEFETIVOS08,QTEFETIVOS09,QTEFETIVOS10, QTEFETIVOS11, QTEFETIVOS12, QTEFETIVOS13,QTEFETIVOS14,
                      QTEFETIVOS15,QTEFETIVOS16,NRAGRUPRAT,NRAGRUPNF,NRAPURACFAT, VRPRECUNIT, CDPRODUTO, DTINIAPLASER,
                      VRPRECUNIT01,VRPRECUNIT02,VRPRECUNIT03,VRPRECUNIT04,VRPRECUNIT05,VRPRECUNIT06,VRPRECUNIT07,
                      VRPRECUNIT08,VRPRECUNIT09,VRPRECUNIT10, VRPRECUNIT11, VRPRECUNIT12, VRPRECUNIT13,VRPRECUNIT14,
                      VRPRECUNIT15,VRPRECUNIT16)
                      VALUES (C_EFETRATCDRS.CDFILIAL, V_NUMECDRS, C_EFETRATCDRS.CDCLIENTE,
                              C_EFETRATCDRS.CDSERVFILI, P_DATA, V_NRQUINZENA,
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '01',C_EFETRATCDRS.QTDERATEIO, '16',C_EFETRATCDRS.QTDERATEIO, 0),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '02',C_EFETRATCDRS.QTDERATEIO, '17',C_EFETRATCDRS.QTDERATEIO, 0),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '03',C_EFETRATCDRS.QTDERATEIO, '18',C_EFETRATCDRS.QTDERATEIO, 0),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '04',C_EFETRATCDRS.QTDERATEIO, '19',C_EFETRATCDRS.QTDERATEIO, 0),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '05',C_EFETRATCDRS.QTDERATEIO, '20',C_EFETRATCDRS.QTDERATEIO, 0),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '06',C_EFETRATCDRS.QTDERATEIO, '21',C_EFETRATCDRS.QTDERATEIO, 0),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '07',C_EFETRATCDRS.QTDERATEIO, '22',C_EFETRATCDRS.QTDERATEIO, 0),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '08',C_EFETRATCDRS.QTDERATEIO, '23',C_EFETRATCDRS.QTDERATEIO, 0),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '09',C_EFETRATCDRS.QTDERATEIO, '24',C_EFETRATCDRS.QTDERATEIO, 0),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '10',C_EFETRATCDRS.QTDERATEIO, '25',C_EFETRATCDRS.QTDERATEIO, 0),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '11',C_EFETRATCDRS.QTDERATEIO, '26',C_EFETRATCDRS.QTDERATEIO, 0),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '12',C_EFETRATCDRS.QTDERATEIO, '27',C_EFETRATCDRS.QTDERATEIO, 0),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '13',C_EFETRATCDRS.QTDERATEIO, '28',C_EFETRATCDRS.QTDERATEIO, 0),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '14',C_EFETRATCDRS.QTDERATEIO, '29',C_EFETRATCDRS.QTDERATEIO, 0),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '15',C_EFETRATCDRS.QTDERATEIO, '30',C_EFETRATCDRS.QTDERATEIO, 0),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '31',C_EFETRATCDRS.QTDERATEIO, 0),
                              C_EFETRATCDRS.NRAGREFRAT,C_EFETCDRS.NRAGRUEFET,P_NRAPURACFAT,C_EFETRATCDRS.VRPRECUNIT,C_EFETRATCDRS.CDPRODUTO, P_DATAINI,
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '01',C_EFETRATCDRS.VRPRECUNIT, '16',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '02',C_EFETRATCDRS.VRPRECUNIT, '17',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '03',C_EFETRATCDRS.VRPRECUNIT, '18',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '04',C_EFETRATCDRS.VRPRECUNIT, '19',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '05',C_EFETRATCDRS.VRPRECUNIT, '20',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '06',C_EFETRATCDRS.VRPRECUNIT, '21',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '07',C_EFETRATCDRS.VRPRECUNIT, '22',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '08',C_EFETRATCDRS.VRPRECUNIT, '23',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '09',C_EFETRATCDRS.VRPRECUNIT, '24',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '10',C_EFETRATCDRS.VRPRECUNIT, '25',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '11',C_EFETRATCDRS.VRPRECUNIT, '26',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '12',C_EFETRATCDRS.VRPRECUNIT, '27',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '13',C_EFETRATCDRS.VRPRECUNIT, '28',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '14',C_EFETRATCDRS.VRPRECUNIT, '29',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '15',C_EFETRATCDRS.VRPRECUNIT, '30',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '31',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT));

                  ELSE
                     UPDATE RELAT_CDRS
                     SET QTEFETIVOS01 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '01',C_EFETRATCDRS.QTDERATEIO, '16',C_EFETRATCDRS.QTDERATEIO, QTEFETIVOS01),
                         QTEFETIVOS02 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '02',C_EFETRATCDRS.QTDERATEIO, '17',C_EFETRATCDRS.QTDERATEIO, QTEFETIVOS02),
                         QTEFETIVOS03 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '03',C_EFETRATCDRS.QTDERATEIO, '18',C_EFETRATCDRS.QTDERATEIO, QTEFETIVOS03),
                         QTEFETIVOS04 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '04',C_EFETRATCDRS.QTDERATEIO, '19',C_EFETRATCDRS.QTDERATEIO, QTEFETIVOS04),
                         QTEFETIVOS05 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '05',C_EFETRATCDRS.QTDERATEIO, '20',C_EFETRATCDRS.QTDERATEIO, QTEFETIVOS05),
                         QTEFETIVOS06 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '06',C_EFETRATCDRS.QTDERATEIO, '21',C_EFETRATCDRS.QTDERATEIO, QTEFETIVOS06),
                         QTEFETIVOS07 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '07',C_EFETRATCDRS.QTDERATEIO, '22',C_EFETRATCDRS.QTDERATEIO, QTEFETIVOS07),
                         QTEFETIVOS08 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '08',C_EFETRATCDRS.QTDERATEIO, '23',C_EFETRATCDRS.QTDERATEIO, QTEFETIVOS08),
                         QTEFETIVOS09 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '09',C_EFETRATCDRS.QTDERATEIO, '24',C_EFETRATCDRS.QTDERATEIO, QTEFETIVOS09),
                         QTEFETIVOS10 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '10',C_EFETRATCDRS.QTDERATEIO, '25',C_EFETRATCDRS.QTDERATEIO, QTEFETIVOS10),
                         QTEFETIVOS11 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '11',C_EFETRATCDRS.QTDERATEIO, '26',C_EFETRATCDRS.QTDERATEIO, QTEFETIVOS11),
                         QTEFETIVOS12 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '12',C_EFETRATCDRS.QTDERATEIO, '27',C_EFETRATCDRS.QTDERATEIO, QTEFETIVOS12),
                         QTEFETIVOS13 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '13',C_EFETRATCDRS.QTDERATEIO, '28',C_EFETRATCDRS.QTDERATEIO, QTEFETIVOS13),
                         QTEFETIVOS14 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '14',C_EFETRATCDRS.QTDERATEIO, '29',C_EFETRATCDRS.QTDERATEIO, QTEFETIVOS14),
                         QTEFETIVOS15 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '15',C_EFETRATCDRS.QTDERATEIO, '30',C_EFETRATCDRS.QTDERATEIO, QTEFETIVOS15),
                         QTEFETIVOS16 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '31',C_EFETRATCDRS.QTDERATEIO, QTEFETIVOS16),

                         VRPRECUNIT01 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '01',C_EFETRATCDRS.VRPRECUNIT, '16',C_EFETRATCDRS.VRPRECUNIT, VRPRECUNIT01),
                         VRPRECUNIT02 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '02',C_EFETRATCDRS.VRPRECUNIT, '17',C_EFETRATCDRS.VRPRECUNIT, VRPRECUNIT02),
                         VRPRECUNIT03 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '03',C_EFETRATCDRS.VRPRECUNIT, '18',C_EFETRATCDRS.VRPRECUNIT, VRPRECUNIT03),
                         VRPRECUNIT04 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '04',C_EFETRATCDRS.VRPRECUNIT, '19',C_EFETRATCDRS.VRPRECUNIT, VRPRECUNIT04),
                         VRPRECUNIT05 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '05',C_EFETRATCDRS.VRPRECUNIT, '20',C_EFETRATCDRS.VRPRECUNIT, VRPRECUNIT05),
                         VRPRECUNIT06 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '06',C_EFETRATCDRS.VRPRECUNIT, '21',C_EFETRATCDRS.VRPRECUNIT, VRPRECUNIT06),
                         VRPRECUNIT07 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '07',C_EFETRATCDRS.VRPRECUNIT, '22',C_EFETRATCDRS.VRPRECUNIT, VRPRECUNIT07),
                         VRPRECUNIT08 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '08',C_EFETRATCDRS.VRPRECUNIT, '23',C_EFETRATCDRS.VRPRECUNIT, VRPRECUNIT08),
                         VRPRECUNIT09 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '09',C_EFETRATCDRS.VRPRECUNIT, '24',C_EFETRATCDRS.VRPRECUNIT, VRPRECUNIT09),
                         VRPRECUNIT10 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '10',C_EFETRATCDRS.VRPRECUNIT, '25',C_EFETRATCDRS.VRPRECUNIT, VRPRECUNIT10),
                         VRPRECUNIT11 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '11',C_EFETRATCDRS.VRPRECUNIT, '26',C_EFETRATCDRS.VRPRECUNIT, VRPRECUNIT11),
                         VRPRECUNIT12 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '12',C_EFETRATCDRS.VRPRECUNIT, '27',C_EFETRATCDRS.VRPRECUNIT, VRPRECUNIT12),
                         VRPRECUNIT13 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '13',C_EFETRATCDRS.VRPRECUNIT, '28',C_EFETRATCDRS.VRPRECUNIT, VRPRECUNIT13),
                         VRPRECUNIT14 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '14',C_EFETRATCDRS.VRPRECUNIT, '29',C_EFETRATCDRS.VRPRECUNIT, VRPRECUNIT14),
                         VRPRECUNIT15 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '15',C_EFETRATCDRS.VRPRECUNIT, '30',C_EFETRATCDRS.VRPRECUNIT, VRPRECUNIT15),
                         VRPRECUNIT16 = DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '31',C_EFETRATCDRS.VRPRECUNIT, VRPRECUNIT16)
                     WHERE CDFILIAL   = C_EFETRATCDRS.CDFILIAL     AND
                           CDCLIENTE  = C_EFETRATCDRS.CDCLIENTE    AND
                           CDSERVFILI = C_EFETRATCDRS.CDSERVFILI   AND
                           NRCDRS     = V_NUMECDRS                 AND
                           DTINIAPLASER BETWEEN P_DATAINI AND P_DATAFIM AND
                           DTCDRS     = P_DATA;
                  END IF;
               ELSE

                  SELECT MAX(NRAGRUPNF), MAX(NRCDRS)
                  INTO V_NRAGRUPNF, V_NUMECDRS
                  FROM RELAT_CDRS
                  WHERE CDFILIAL = C_EFETRATCDRS.CDFILIAL     AND
                        CDCLIENTE = C_EFETRATCDRS.CDCLIENTE   AND
                        DTINIAPLASER BETWEEN P_DATAINI AND P_DATAFIM AND
                        DTCDRS =  P_DATA                      AND
                        NRQUINZENA = V_NRQUINZENA             AND
                        NRAGRUPNF  = C_EFETCDRS.NRAGRUEFET    AND
                        NRAGRUPRAT  = C_EFETRATCDRS.NRAGREFRAT;

                  IF (V_NRAGRUPNF IS NULL) OR (V_CONT = 13) THEN
                     NUMERO_CDRS('NUMECDRS'||C_EFETRATCDRS.CDFILIAL||C_EFETRATCDRS.CDCLIENTE,V_NUMECDRS);

                      SELECT COUNT(*)
                      INTO V_EXISTE
                      FROM RELAT_CDRS
                      WHERE CDFILIAL = C_EFETRATCDRS.CDFILIAL     AND
                            CDCLIENTE = C_EFETRATCDRS.CDCLIENTE   AND
                            NRCDRS = V_NUMECDRS;

                      IF V_EXISTE > 0 THEN
                         WHILE V_EXISTE > 0 LOOP
                            V_NUMECDRS := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_NUMECDRS) + 1)),10,'0');

                            SELECT COUNT(*)
                            INTO V_EXISTE
                            FROM RELAT_CDRS
                            WHERE CDFILIAL = C_EFETRATCDRS.CDFILIAL     AND
                                  CDCLIENTE = C_EFETRATCDRS.CDCLIENTE   AND
                                  NRCDRS = V_NUMECDRS;
                         END LOOP;

                         UPDATE NOVOCODIGO
                         SET NRSEQUENCIAL = V_NUMECDRS
                         WHERE CDCONTADOR = 'NUMECDRS'||C_EFETRATCDRS.CDFILIAL||C_EFETRATCDRS.CDCLIENTE;

                      END IF;

                  END IF;

                  INSERT INTO RELAT_CDRS
                  (CDFILIAL, NRCDRS, CDCLIENTE,
                   CDSERVFILI, DTCDRS, NRQUINZENA,
                   QTEFETIVOS01,QTEFETIVOS02,QTEFETIVOS03,QTEFETIVOS04,QTEFETIVOS05,QTEFETIVOS06,QTEFETIVOS07,
                   QTEFETIVOS08,QTEFETIVOS09,QTEFETIVOS10, QTEFETIVOS11, QTEFETIVOS12, QTEFETIVOS13,QTEFETIVOS14,
                   QTEFETIVOS15,QTEFETIVOS16,NRAGRUPRAT,NRAGRUPNF,NRAPURACFAT,VRPRECUNIT,CDPRODUTO, DTINIAPLASER,
                   VRPRECUNIT01,VRPRECUNIT02,VRPRECUNIT03,VRPRECUNIT04,VRPRECUNIT05,VRPRECUNIT06,VRPRECUNIT07,
                   VRPRECUNIT08,VRPRECUNIT09,VRPRECUNIT10, VRPRECUNIT11, VRPRECUNIT12, VRPRECUNIT13,VRPRECUNIT14,
                   VRPRECUNIT15,VRPRECUNIT16)
                   VALUES (C_EFETRATCDRS.CDFILIAL, V_NUMECDRS, C_EFETRATCDRS.CDCLIENTE,
                           C_EFETRATCDRS.CDSERVFILI, P_DATA, V_NRQUINZENA,
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '01',C_EFETRATCDRS.QTDERATEIO, '16',C_EFETRATCDRS.QTDERATEIO, 0),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '02',C_EFETRATCDRS.QTDERATEIO, '17',C_EFETRATCDRS.QTDERATEIO, 0),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '03',C_EFETRATCDRS.QTDERATEIO, '18',C_EFETRATCDRS.QTDERATEIO, 0),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '04',C_EFETRATCDRS.QTDERATEIO, '19',C_EFETRATCDRS.QTDERATEIO, 0),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '05',C_EFETRATCDRS.QTDERATEIO, '20',C_EFETRATCDRS.QTDERATEIO, 0),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '06',C_EFETRATCDRS.QTDERATEIO, '21',C_EFETRATCDRS.QTDERATEIO, 0),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '07',C_EFETRATCDRS.QTDERATEIO, '22',C_EFETRATCDRS.QTDERATEIO, 0),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '08',C_EFETRATCDRS.QTDERATEIO, '23',C_EFETRATCDRS.QTDERATEIO, 0),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '09',C_EFETRATCDRS.QTDERATEIO, '24',C_EFETRATCDRS.QTDERATEIO, 0),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '10',C_EFETRATCDRS.QTDERATEIO, '25',C_EFETRATCDRS.QTDERATEIO, 0),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '11',C_EFETRATCDRS.QTDERATEIO, '26',C_EFETRATCDRS.QTDERATEIO, 0),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '12',C_EFETRATCDRS.QTDERATEIO, '27',C_EFETRATCDRS.QTDERATEIO, 0),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '13',C_EFETRATCDRS.QTDERATEIO, '28',C_EFETRATCDRS.QTDERATEIO, 0),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '14',C_EFETRATCDRS.QTDERATEIO, '29',C_EFETRATCDRS.QTDERATEIO, 0),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '15',C_EFETRATCDRS.QTDERATEIO, '30',C_EFETRATCDRS.QTDERATEIO, 0),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '31',C_EFETRATCDRS.QTDERATEIO, 0),
                           C_EFETRATCDRS.NRAGREFRAT,C_EFETCDRS.NRAGRUEFET,P_NRAPURACFAT,C_EFETRATCDRS.VRPRECUNIT,C_EFETRATCDRS.CDPRODUTO, P_DATAINI,
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '01',C_EFETRATCDRS.VRPRECUNIT, '16',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '02',C_EFETRATCDRS.VRPRECUNIT, '17',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '03',C_EFETRATCDRS.VRPRECUNIT, '18',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '04',C_EFETRATCDRS.VRPRECUNIT, '19',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '05',C_EFETRATCDRS.VRPRECUNIT, '20',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '06',C_EFETRATCDRS.VRPRECUNIT, '21',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '07',C_EFETRATCDRS.VRPRECUNIT, '22',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '08',C_EFETRATCDRS.VRPRECUNIT, '23',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '09',C_EFETRATCDRS.VRPRECUNIT, '24',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '10',C_EFETRATCDRS.VRPRECUNIT, '25',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '11',C_EFETRATCDRS.VRPRECUNIT, '26',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '12',C_EFETRATCDRS.VRPRECUNIT, '27',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '13',C_EFETRATCDRS.VRPRECUNIT, '28',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '14',C_EFETRATCDRS.VRPRECUNIT, '29',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '15',C_EFETRATCDRS.VRPRECUNIT, '30',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT),
                           DECODE(TO_CHAR(C_EFETRATCDRS.DTRATCDRS, 'DD'), '31',C_EFETRATCDRS.VRPRECUNIT, C_EFETRATCDRS.VRPRECUNIT));

               END IF;


            END LOOP;

            IF V_MDNRAGRUP = 'S' THEN      /*GRAVA OS SERVICOS QUE NAO POSSUEM RATEIO*/
               FOR C_EFETCDRSDIA IN(
                              SELECT NRAGRUEFET, CDSERVFILI, CDFILIAL, CDCLIENTE, QTCOMECDRS, DTEFETCDRS, VRPRECEFET AS VRPRECUNIT, CDPRODUTO
                              FROM
                                EFETCDRS
                              WHERE
                                 (CDFILIAL   = C_EFETAGRUP.CDFILIAL)              AND
                                 (CDCLIENTE  = P_CDCLIENTE)                      AND
                                 (DTEFETCDRS BETWEEN P_DATAINI AND P_DATAFIM)     AND
                                 (NRAGRUEFET  = C_EFETCDRS.NRAGRUEFET)             AND
                                 (NOT EXISTS (SELECT DTRATCDRS FROM EFETRATCDRS
                                              WHERE (EFETCDRS.CDFILIAL   = EFETRATCDRS.CDFILIAL)  AND
                                                    (EFETCDRS.CDCLIENTE  = EFETRATCDRS.CDCLIENTE) AND
                                                    (EFETCDRS.CDSERVFILI = EFETRATCDRS.CDSERVFILI) AND
                                                    (EFETCDRS.DTEFETCDRS = EFETRATCDRS.DTRATCDRS)))
                              ORDER BY NRAGRUEFET, CDSERVFILI ) LOOP

                  IF TO_NUMBER(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD')) <= 15 THEN
                     V_NRQUINZENA := 1;
                     P_DATA := TO_DATE('01/'||TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'MM')||'/'||TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'YYYY'),'DD/MM/YYYY');
                  ELSE
                     V_NRQUINZENA := 2;
                     P_DATA := TO_DATE('16/'||TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'MM')||'/'||TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'YYYY'),'DD/MM/YYYY');
                  END IF;

                  SELECT MAX(NRAGRUPNF), MAX(NRCDRS)
                  INTO V_NRAGRUPNF, V_NUMECDRS
                  FROM RELAT_CDRS
                  WHERE CDFILIAL   = C_EFETCDRSDIA.CDFILIAL     AND
                        CDCLIENTE  = C_EFETCDRSDIA.CDCLIENTE    AND
                        CDSERVFILI = C_EFETCDRSDIA.CDSERVFILI   AND
                        DTINIAPLASER BETWEEN P_DATAINI AND P_DATAFIM AND
                        DTCDRS =  P_DATA                      AND
                        NRQUINZENA = V_NRQUINZENA               AND
                        NRAGRUPNF  = C_EFETCDRS.NRAGRUEFET      AND
                        NRAGRUPRAT = C_EFETCDRS.NRAGRUEFET;

                  SELECT COUNT(*)
                  INTO V_CONT
                  FROM RELAT_CDRS
                  WHERE CDFILIAL   = C_EFETCDRSDIA.CDFILIAL     AND
                        CDCLIENTE  = C_EFETCDRSDIA.CDCLIENTE    AND
                        DTINIAPLASER BETWEEN P_DATAINI AND P_DATAFIM AND
                        DTCDRS =  P_DATA                      AND
                        NRQUINZENA = V_NRQUINZENA               AND
                        NRAGRUPNF  = C_EFETCDRS.NRAGRUEFET      AND
                        NRAGRUPRAT = C_EFETCDRS.NRAGRUEFET;

                  IF NOT V_NRAGRUPNF IS NULL THEN
                     IF V_CONT = 13 THEN
                        NUMERO_CDRS('NUMECDRS'||C_EFETCDRSDIA.CDFILIAL||C_EFETCDRSDIA.CDCLIENTE,V_NUMECDRS);
                        SELECT COUNT(*)
                        INTO V_EXISTE
                        FROM RELAT_CDRS
                        WHERE CDFILIAL = C_EFETCDRSDIA.CDFILIAL     AND
                              CDCLIENTE = C_EFETCDRSDIA.CDCLIENTE   AND
                              NRCDRS = V_NUMECDRS;

                        IF V_EXISTE > 0 THEN
                           WHILE V_EXISTE > 0 LOOP
                              V_NUMECDRS := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_NUMECDRS) + 1)),10,'0');

                              SELECT COUNT(*)
                              INTO V_EXISTE
                              FROM RELAT_CDRS
                              WHERE CDFILIAL = C_EFETCDRSDIA.CDFILIAL     AND
                                    CDCLIENTE = C_EFETCDRSDIA.CDCLIENTE   AND
                                    NRCDRS = V_NUMECDRS;
                           END LOOP;

                           UPDATE NOVOCODIGO
                           SET NRSEQUENCIAL = V_NUMECDRS
                           WHERE CDCONTADOR = 'NUMECDRS'||C_EFETCDRSDIA.CDFILIAL||C_EFETCDRSDIA.CDCLIENTE;
                        END IF;

                        INSERT INTO RELAT_CDRS
                        (CDFILIAL, NRCDRS, CDCLIENTE,
                         CDSERVFILI, DTCDRS, NRQUINZENA,
                         QTEFETIVOS01,QTEFETIVOS02,QTEFETIVOS03,QTEFETIVOS04,QTEFETIVOS05,QTEFETIVOS06,QTEFETIVOS07,
                         QTEFETIVOS08,QTEFETIVOS09,QTEFETIVOS10, QTEFETIVOS11, QTEFETIVOS12, QTEFETIVOS13,QTEFETIVOS14,
                         QTEFETIVOS15,QTEFETIVOS16,NRAGRUPRAT,NRAGRUPNF,NRAPURACFAT,VRPRECUNIT,CDPRODUTO, DTINIAPLASER,
                         VRPRECUNIT01,VRPRECUNIT02,VRPRECUNIT03,VRPRECUNIT04,VRPRECUNIT05,VRPRECUNIT06,VRPRECUNIT07,
                         VRPRECUNIT08,VRPRECUNIT09,VRPRECUNIT10, VRPRECUNIT11, VRPRECUNIT12, VRPRECUNIT13,VRPRECUNIT14,
                         VRPRECUNIT15,VRPRECUNIT16)
                         VALUES (C_EFETCDRSDIA.CDFILIAL, V_NUMECDRS, C_EFETCDRSDIA.CDCLIENTE,
                                 C_EFETCDRSDIA.CDSERVFILI, P_DATA, V_NRQUINZENA,
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '01',C_EFETCDRSDIA.QTCOMECDRS, '16',C_EFETCDRSDIA.QTCOMECDRS, 0),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '02',C_EFETCDRSDIA.QTCOMECDRS, '17',C_EFETCDRSDIA.QTCOMECDRS, 0),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '03',C_EFETCDRSDIA.QTCOMECDRS, '18',C_EFETCDRSDIA.QTCOMECDRS, 0),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '04',C_EFETCDRSDIA.QTCOMECDRS, '19',C_EFETCDRSDIA.QTCOMECDRS, 0),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '05',C_EFETCDRSDIA.QTCOMECDRS, '20',C_EFETCDRSDIA.QTCOMECDRS, 0),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '06',C_EFETCDRSDIA.QTCOMECDRS, '21',C_EFETCDRSDIA.QTCOMECDRS, 0),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '07',C_EFETCDRSDIA.QTCOMECDRS, '22',C_EFETCDRSDIA.QTCOMECDRS, 0),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '08',C_EFETCDRSDIA.QTCOMECDRS, '23',C_EFETCDRSDIA.QTCOMECDRS, 0),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '09',C_EFETCDRSDIA.QTCOMECDRS, '24',C_EFETCDRSDIA.QTCOMECDRS, 0),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '10',C_EFETCDRSDIA.QTCOMECDRS, '25',C_EFETCDRSDIA.QTCOMECDRS, 0),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '11',C_EFETCDRSDIA.QTCOMECDRS, '26',C_EFETCDRSDIA.QTCOMECDRS, 0),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '12',C_EFETCDRSDIA.QTCOMECDRS, '27',C_EFETCDRSDIA.QTCOMECDRS, 0),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '13',C_EFETCDRSDIA.QTCOMECDRS, '28',C_EFETCDRSDIA.QTCOMECDRS, 0),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '14',C_EFETCDRSDIA.QTCOMECDRS, '29',C_EFETCDRSDIA.QTCOMECDRS, 0),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '15',C_EFETCDRSDIA.QTCOMECDRS, '30',C_EFETCDRSDIA.QTCOMECDRS, 0),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '31',C_EFETCDRSDIA.QTCOMECDRS, 0),
                                 C_EFETCDRS.NRAGRUEFET,C_EFETCDRS.NRAGRUEFET,P_NRAPURACFAT,C_EFETCDRSDIA.VRPRECUNIT,C_EFETCDRSDIA.CDPRODUTO, P_DATAINI,
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '01',C_EFETCDRSDIA.VRPRECUNIT, '16',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '02',C_EFETCDRSDIA.VRPRECUNIT, '17',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '03',C_EFETCDRSDIA.VRPRECUNIT, '18',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '04',C_EFETCDRSDIA.VRPRECUNIT, '19',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '05',C_EFETCDRSDIA.VRPRECUNIT, '20',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '06',C_EFETCDRSDIA.VRPRECUNIT, '21',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '07',C_EFETCDRSDIA.VRPRECUNIT, '22',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '08',C_EFETCDRSDIA.VRPRECUNIT, '23',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '09',C_EFETCDRSDIA.VRPRECUNIT, '24',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '10',C_EFETCDRSDIA.VRPRECUNIT, '25',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '11',C_EFETCDRSDIA.VRPRECUNIT, '26',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '12',C_EFETCDRSDIA.VRPRECUNIT, '27',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '13',C_EFETCDRSDIA.VRPRECUNIT, '28',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '14',C_EFETCDRSDIA.VRPRECUNIT, '29',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '15',C_EFETCDRSDIA.VRPRECUNIT, '30',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                                 DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '31',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT));

                     ELSE
                        UPDATE RELAT_CDRS
                        SET QTEFETIVOS01 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '01',C_EFETCDRSDIA.QTCOMECDRS, '16',C_EFETCDRSDIA.QTCOMECDRS, QTEFETIVOS01),
                            QTEFETIVOS02 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '02',C_EFETCDRSDIA.QTCOMECDRS, '17',C_EFETCDRSDIA.QTCOMECDRS, QTEFETIVOS02),
                            QTEFETIVOS03 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '03',C_EFETCDRSDIA.QTCOMECDRS, '18',C_EFETCDRSDIA.QTCOMECDRS, QTEFETIVOS03),
                            QTEFETIVOS04 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '04',C_EFETCDRSDIA.QTCOMECDRS, '19',C_EFETCDRSDIA.QTCOMECDRS, QTEFETIVOS04),
                            QTEFETIVOS05 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '05',C_EFETCDRSDIA.QTCOMECDRS, '20',C_EFETCDRSDIA.QTCOMECDRS, QTEFETIVOS05),
                            QTEFETIVOS06 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '06',C_EFETCDRSDIA.QTCOMECDRS, '21',C_EFETCDRSDIA.QTCOMECDRS, QTEFETIVOS06),
                            QTEFETIVOS07 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '07',C_EFETCDRSDIA.QTCOMECDRS, '22',C_EFETCDRSDIA.QTCOMECDRS, QTEFETIVOS07),
                            QTEFETIVOS08 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '08',C_EFETCDRSDIA.QTCOMECDRS, '23',C_EFETCDRSDIA.QTCOMECDRS, QTEFETIVOS08),
                            QTEFETIVOS09 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '09',C_EFETCDRSDIA.QTCOMECDRS, '24',C_EFETCDRSDIA.QTCOMECDRS, QTEFETIVOS09),
                            QTEFETIVOS10 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '10',C_EFETCDRSDIA.QTCOMECDRS, '25',C_EFETCDRSDIA.QTCOMECDRS, QTEFETIVOS10),
                            QTEFETIVOS11 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '11',C_EFETCDRSDIA.QTCOMECDRS, '26',C_EFETCDRSDIA.QTCOMECDRS, QTEFETIVOS11),
                            QTEFETIVOS12 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '12',C_EFETCDRSDIA.QTCOMECDRS, '27',C_EFETCDRSDIA.QTCOMECDRS, QTEFETIVOS12),
                            QTEFETIVOS13 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '13',C_EFETCDRSDIA.QTCOMECDRS, '28',C_EFETCDRSDIA.QTCOMECDRS, QTEFETIVOS13),
                            QTEFETIVOS14 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '14',C_EFETCDRSDIA.QTCOMECDRS, '29',C_EFETCDRSDIA.QTCOMECDRS, QTEFETIVOS14),
                            QTEFETIVOS15 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '15',C_EFETCDRSDIA.QTCOMECDRS, '30',C_EFETCDRSDIA.QTCOMECDRS, QTEFETIVOS15),
                            QTEFETIVOS16 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '31',C_EFETCDRSDIA.QTCOMECDRS, QTEFETIVOS16),

                            VRPRECUNIT01 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '01',C_EFETCDRSDIA.VRPRECUNIT, '16',C_EFETCDRSDIA.VRPRECUNIT, VRPRECUNIT01),
                            VRPRECUNIT02 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '02',C_EFETCDRSDIA.VRPRECUNIT, '17',C_EFETCDRSDIA.VRPRECUNIT, VRPRECUNIT02),
                            VRPRECUNIT03 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '03',C_EFETCDRSDIA.VRPRECUNIT, '18',C_EFETCDRSDIA.VRPRECUNIT, VRPRECUNIT03),
                            VRPRECUNIT04 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '04',C_EFETCDRSDIA.VRPRECUNIT, '19',C_EFETCDRSDIA.VRPRECUNIT, VRPRECUNIT04),
                            VRPRECUNIT05 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '05',C_EFETCDRSDIA.VRPRECUNIT, '20',C_EFETCDRSDIA.VRPRECUNIT, VRPRECUNIT05),
                            VRPRECUNIT06 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '06',C_EFETCDRSDIA.VRPRECUNIT, '21',C_EFETCDRSDIA.VRPRECUNIT, VRPRECUNIT06),
                            VRPRECUNIT07 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '07',C_EFETCDRSDIA.VRPRECUNIT, '22',C_EFETCDRSDIA.VRPRECUNIT, VRPRECUNIT07),
                            VRPRECUNIT08 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '08',C_EFETCDRSDIA.VRPRECUNIT, '23',C_EFETCDRSDIA.VRPRECUNIT, VRPRECUNIT08),
                            VRPRECUNIT09 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '09',C_EFETCDRSDIA.VRPRECUNIT, '24',C_EFETCDRSDIA.VRPRECUNIT, VRPRECUNIT09),
                            VRPRECUNIT10 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '10',C_EFETCDRSDIA.VRPRECUNIT, '25',C_EFETCDRSDIA.VRPRECUNIT, VRPRECUNIT10),
                            VRPRECUNIT11 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '11',C_EFETCDRSDIA.VRPRECUNIT, '26',C_EFETCDRSDIA.VRPRECUNIT, VRPRECUNIT11),
                            VRPRECUNIT12 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '12',C_EFETCDRSDIA.VRPRECUNIT, '27',C_EFETCDRSDIA.VRPRECUNIT, VRPRECUNIT12),
                            VRPRECUNIT13 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '13',C_EFETCDRSDIA.VRPRECUNIT, '28',C_EFETCDRSDIA.VRPRECUNIT, VRPRECUNIT13),
                            VRPRECUNIT14 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '14',C_EFETCDRSDIA.VRPRECUNIT, '29',C_EFETCDRSDIA.VRPRECUNIT, VRPRECUNIT14),
                            VRPRECUNIT15 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '15',C_EFETCDRSDIA.VRPRECUNIT, '30',C_EFETCDRSDIA.VRPRECUNIT, VRPRECUNIT15),
                            VRPRECUNIT16 = DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '31',C_EFETCDRSDIA.VRPRECUNIT, VRPRECUNIT16)
                        WHERE CDFILIAL   = C_EFETCDRSDIA.CDFILIAL     AND
                              CDCLIENTE  = C_EFETCDRSDIA.CDCLIENTE    AND
                              CDSERVFILI = C_EFETCDRSDIA.CDSERVFILI   AND
                              NRCDRS     = V_NUMECDRS                 AND
                              DTINIAPLASER BETWEEN P_DATAINI AND P_DATAFIM AND
                              DTCDRS     = P_DATA ;

                     END IF;
                  ELSE

                     SELECT MAX(NRAGRUPNF), MAX(NRCDRS)
                     INTO V_NRAGRUPNF, V_NUMECDRS
                     FROM RELAT_CDRS
                     WHERE CDFILIAL = C_EFETCDRSDIA.CDFILIAL     AND
                           CDCLIENTE = C_EFETCDRSDIA.CDCLIENTE   AND
                           DTINIAPLASER BETWEEN P_DATAINI AND P_DATAFIM AND
                           DTCDRS =  P_DATA                      AND
                           NRQUINZENA = V_NRQUINZENA             AND
                           NRAGRUPNF  = C_EFETCDRS.NRAGRUEFET    AND
                           NRAGRUPRAT = C_EFETCDRS.NRAGRUEFET;

                     IF (V_NRAGRUPNF IS NULL) OR (V_CONT = 13) THEN
                        NUMERO_CDRS('NUMECDRS'||C_EFETCDRSDIA.CDFILIAL||C_EFETCDRSDIA.CDCLIENTE,V_NUMECDRS);
                        SELECT COUNT(*)
                        INTO V_EXISTE
                        FROM RELAT_CDRS
                        WHERE CDFILIAL = C_EFETCDRSDIA.CDFILIAL     AND
                              CDCLIENTE = C_EFETCDRSDIA.CDCLIENTE   AND
                              NRCDRS = V_NUMECDRS;

                        IF V_EXISTE > 0 THEN
                           WHILE V_EXISTE > 0 LOOP
                              V_NUMECDRS := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_NUMECDRS) + 1)),10,'0');

                              SELECT COUNT(*)
                              INTO V_EXISTE
                              FROM RELAT_CDRS
                              WHERE CDFILIAL = C_EFETCDRSDIA.CDFILIAL     AND
                                    CDCLIENTE = C_EFETCDRSDIA.CDCLIENTE   AND
                                    NRCDRS = V_NUMECDRS;
                           END LOOP;

                           UPDATE NOVOCODIGO
                           SET NRSEQUENCIAL = V_NUMECDRS
                           WHERE CDCONTADOR = 'NUMECDRS'||C_EFETCDRSDIA.CDFILIAL||C_EFETCDRSDIA.CDCLIENTE;
                        END IF;
                     END IF;

                     INSERT INTO RELAT_CDRS
                     (CDFILIAL, NRCDRS, CDCLIENTE,
                      CDSERVFILI, DTCDRS, NRQUINZENA,
                      QTEFETIVOS01,QTEFETIVOS02,QTEFETIVOS03,QTEFETIVOS04,QTEFETIVOS05,QTEFETIVOS06,QTEFETIVOS07,
                      QTEFETIVOS08,QTEFETIVOS09,QTEFETIVOS10, QTEFETIVOS11, QTEFETIVOS12, QTEFETIVOS13,QTEFETIVOS14,
                      QTEFETIVOS15,QTEFETIVOS16,NRAGRUPRAT,NRAGRUPNF,NRAPURACFAT,VRPRECUNIT,CDPRODUTO, DTINIAPLASER,
                      VRPRECUNIT01,VRPRECUNIT02,VRPRECUNIT03,VRPRECUNIT04,VRPRECUNIT05,VRPRECUNIT06,VRPRECUNIT07,
                      VRPRECUNIT08,VRPRECUNIT09,VRPRECUNIT10, VRPRECUNIT11, VRPRECUNIT12, VRPRECUNIT13,VRPRECUNIT14,
                      VRPRECUNIT15,VRPRECUNIT16)
                      VALUES (C_EFETCDRSDIA.CDFILIAL, V_NUMECDRS, C_EFETCDRSDIA.CDCLIENTE,
                              C_EFETCDRSDIA.CDSERVFILI, P_DATA, V_NRQUINZENA,
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '01',C_EFETCDRSDIA.QTCOMECDRS, '16',C_EFETCDRSDIA.QTCOMECDRS, 0),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '02',C_EFETCDRSDIA.QTCOMECDRS, '17',C_EFETCDRSDIA.QTCOMECDRS, 0),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '03',C_EFETCDRSDIA.QTCOMECDRS, '18',C_EFETCDRSDIA.QTCOMECDRS, 0),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '04',C_EFETCDRSDIA.QTCOMECDRS, '19',C_EFETCDRSDIA.QTCOMECDRS, 0),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '05',C_EFETCDRSDIA.QTCOMECDRS, '20',C_EFETCDRSDIA.QTCOMECDRS, 0),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '06',C_EFETCDRSDIA.QTCOMECDRS, '21',C_EFETCDRSDIA.QTCOMECDRS, 0),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '07',C_EFETCDRSDIA.QTCOMECDRS, '22',C_EFETCDRSDIA.QTCOMECDRS, 0),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '08',C_EFETCDRSDIA.QTCOMECDRS, '23',C_EFETCDRSDIA.QTCOMECDRS, 0),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '09',C_EFETCDRSDIA.QTCOMECDRS, '24',C_EFETCDRSDIA.QTCOMECDRS, 0),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '10',C_EFETCDRSDIA.QTCOMECDRS, '25',C_EFETCDRSDIA.QTCOMECDRS, 0),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '11',C_EFETCDRSDIA.QTCOMECDRS, '26',C_EFETCDRSDIA.QTCOMECDRS, 0),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '12',C_EFETCDRSDIA.QTCOMECDRS, '27',C_EFETCDRSDIA.QTCOMECDRS, 0),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '13',C_EFETCDRSDIA.QTCOMECDRS, '28',C_EFETCDRSDIA.QTCOMECDRS, 0),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '14',C_EFETCDRSDIA.QTCOMECDRS, '29',C_EFETCDRSDIA.QTCOMECDRS, 0),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '15',C_EFETCDRSDIA.QTCOMECDRS, '30',C_EFETCDRSDIA.QTCOMECDRS, 0),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '31',C_EFETCDRSDIA.QTCOMECDRS, 0),
                              C_EFETCDRS.NRAGRUEFET,C_EFETCDRS.NRAGRUEFET,P_NRAPURACFAT,C_EFETCDRSDIA.VRPRECUNIT,C_EFETCDRSDIA.CDPRODUTO, P_DATAINI,
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '01',C_EFETCDRSDIA.VRPRECUNIT, '16',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '02',C_EFETCDRSDIA.VRPRECUNIT, '17',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '03',C_EFETCDRSDIA.VRPRECUNIT, '18',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '04',C_EFETCDRSDIA.VRPRECUNIT, '19',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '05',C_EFETCDRSDIA.VRPRECUNIT, '20',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '06',C_EFETCDRSDIA.VRPRECUNIT, '21',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '07',C_EFETCDRSDIA.VRPRECUNIT, '22',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '08',C_EFETCDRSDIA.VRPRECUNIT, '23',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '09',C_EFETCDRSDIA.VRPRECUNIT, '24',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '10',C_EFETCDRSDIA.VRPRECUNIT, '25',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '11',C_EFETCDRSDIA.VRPRECUNIT, '26',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '12',C_EFETCDRSDIA.VRPRECUNIT, '27',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '13',C_EFETCDRSDIA.VRPRECUNIT, '28',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '14',C_EFETCDRSDIA.VRPRECUNIT, '29',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '15',C_EFETCDRSDIA.VRPRECUNIT, '30',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT),
                              DECODE(TO_CHAR(C_EFETCDRSDIA.DTEFETCDRS, 'DD'), '31',C_EFETCDRSDIA.VRPRECUNIT, C_EFETCDRSDIA.VRPRECUNIT));

                  END IF;

               END LOOP;
               V_MDNRAGRUP := 'N';
            END IF;
         END LOOP;

         FOR C_RELAT_CDRS IN (SELECT DISTINCT(R.NRAGRUPRAT) AS NRAGRUPRAT
                              FROM RELAT_CDRS R
                              WHERE (R.CDFILIAL    = V_CDFILIAPUR)  AND
                                    (R.CDCLIENTE   = P_CDCLIENTE)          AND
                                    ((R.DTCDRS BETWEEN P_DATAINI AND P_DATAFIM) OR
                                     (R.DTINIAPLASER BETWEEN P_DATAINI AND P_DATAFIM)) AND
                                    (R.NRAGRUPNF   = C_EFETCDRS.NRAGRUEFET)) LOOP

            V_IDNOVANOTA := 'N';
            V_CONTITEM   := V_TTITENSNF;

            FOR C_RELAT_AGRUP IN (SELECT 0 AS QT1, MAX(R.CDFILIAL) AS CDFILIAL, MAX(R.CDCLIENTE) AS CDCLIENTE,
                                         MAX(P.NMPRODUTO) AS NMPRODUTO,
                                         R.CDSERVFILI, MAX(R.CDPRODUTO) AS CDPRODUTO,
                                         NVL(SUM(R.QTEFETIVOS01),0) AS QTEFETIVOS01, NVL(SUM(R.QTEFETIVOS02),0) AS QTEFETIVOS02, NVL(SUM(R.QTEFETIVOS03),0) AS QTEFETIVOS03,
                                         NVL(SUM(R.QTEFETIVOS04),0) AS QTEFETIVOS04, NVL(SUM(R.QTEFETIVOS05),0) AS QTEFETIVOS05, NVL(SUM(R.QTEFETIVOS06),0) AS QTEFETIVOS06,
                                         NVL(SUM(R.QTEFETIVOS07),0) AS QTEFETIVOS07, NVL(SUM(R.QTEFETIVOS08),0) AS QTEFETIVOS08, NVL(SUM(R.QTEFETIVOS09),0) AS QTEFETIVOS09,
                                         NVL(SUM(R.QTEFETIVOS10),0) AS QTEFETIVOS10, NVL(SUM(R.QTEFETIVOS11),0) AS QTEFETIVOS11, NVL(SUM(R.QTEFETIVOS12),0) AS QTEFETIVOS12,
                                         NVL(SUM(R.QTEFETIVOS13),0) AS QTEFETIVOS13, NVL(SUM(R.QTEFETIVOS14),0) AS QTEFETIVOS14, NVL(SUM(R.QTEFETIVOS15),0) AS QTEFETIVOS15,
                                         NVL(SUM(R.QTEFETIVOS16),0) AS QTEFETIVOS16,
                                         VRPRECUNIT01,VRPRECUNIT02,VRPRECUNIT03,VRPRECUNIT04,VRPRECUNIT05,VRPRECUNIT06,VRPRECUNIT07,
                                         VRPRECUNIT08,VRPRECUNIT09,VRPRECUNIT10, VRPRECUNIT11, VRPRECUNIT12, VRPRECUNIT13,VRPRECUNIT14,
                                         VRPRECUNIT15,VRPRECUNIT16
                                  FROM RELAT_CDRS R, PRODUTO P
                                  WHERE (R.CDFILIAL    = V_CDFILIAPUR)             AND
                                        (R.CDCLIENTE   = P_CDCLIENTE)              AND
                                        ((R.DTCDRS BETWEEN P_DATAINI AND P_DATAFIM) OR
                                        (R.DTINIAPLASER BETWEEN P_DATAINI AND P_DATAFIM)) AND
                                        (R.NRAGRUPNF   = C_EFETCDRS.NRAGRUEFET)    AND
                                        (R.NRAGRUPRAT  = C_RELAT_CDRS.NRAGRUPRAT)  AND
                                        (R.CDPRODUTO   = P.CDPRODUTO)
                                  GROUP BY R.CDSERVFILI,
                                           VRPRECUNIT01,VRPRECUNIT02,VRPRECUNIT03,VRPRECUNIT04,VRPRECUNIT05,VRPRECUNIT06,VRPRECUNIT07,
                                           VRPRECUNIT08,VRPRECUNIT09,VRPRECUNIT10, VRPRECUNIT11, VRPRECUNIT12, VRPRECUNIT13,VRPRECUNIT14,
                                           VRPRECUNIT15,VRPRECUNIT16
                                  ORDER BY CDSERVFILI, CDPRODUTO) LOOP

               FOR C_RELAT_PRECO IN (SELECT DISTINCT VRPRECEFET
                                     FROM EFETCDRS
                                     WHERE (CDFILIAL = V_CDFILIAPUR)   AND
                                           (CDCLIENTE   = P_CDCLIENTE) AND
                                           (DTEFETCDRS BETWEEN P_DATAINI AND P_DATAFIM) AND
                                           (CDSERVFILI = C_RELAT_AGRUP.CDSERVFILI))LOOP


                  V_SOMAQT := 0;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT01 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS01;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT02   THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS02;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT03 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS03;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT04 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS04;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT05 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS05;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT06 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS06;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT07 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS07;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT08 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS08;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT09 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS09;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT10 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS10;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT11 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS11;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT12 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS12;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT13 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS13;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT14 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS14;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT15 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS15;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT16 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS16;
                  END IF;


                  IF V_SOMAQT <> 0 THEN
                     IF (V_CONTITEM = V_TTITENSNF) THEN
                      /* EFETUA O FECHAMENTO DA NOTA, GERACAO DE IMPOSTOS */
                        IF (V_IDNOVANOTA = 'S') THEN
                           GERA_NOTAFISCAL_FECHAMENTO(P_CDFILIAL, V_NRLANCTONF);
                        END IF;

                        V_IDNOVANOTA := 'S';
                        V_CONTITEM   := 0;

                        NOVO_CODIGO('LANCNF/FILIAL' || P_CDFILIAL,V_NRLANCTONF);
                        V_NRLANCTONF := SUBSTR(V_NRLANCTONF,11,10);

                        V_NRSEQITPROD := '0000';
                         V_IDGERAREL := 'S';

                        GERA_NOTAFISCAL_CORPO (P_CDFILIAL,    V_CDFILIAPUR, V_CDEMPRESA,
                                               '01',          V_CDSERIE,    P_CDCLIENTE,
                                               P_DATAFIM,     'FAI',        V_NRLANCTONF,
                                               V_PRXLANCESTQ, 'N',          P_NRAPURACFAT,
                                               V_NRLANCTONF);


                        IF (V_DESCDOTACAO = '1') AND (V_VRCREDIDEBI <> 0) AND (V_ENCARGO IS NOT NULL) THEN
                           GERA_NOTAFISCAL_ENCARGO(P_CDFILIAL, V_NRLANCTONF, V_ENCARGO, V_VRCREDIDEBI);
                        END IF;

                     END IF;

                     V_NRSEQITPROD := LPAD((TO_NUMBER(NVL(V_NRSEQITPROD,'0000')) + 1), 4, 0);
                     V_CONTITEM := V_CONTITEM + 1;

                     GERA_NOTAFISCAL_PRODUTO(P_CDFILIAL, V_NRLANCTONF, C_RELAT_AGRUP.CDPRODUTO,
                                             C_RELAT_AGRUP.CDPRODUTO, C_RELAT_AGRUP.NMPRODUTO,
                                             V_SOMAQT, C_RELAT_PRECO.VRPRECEFET,0,NULL,NULL,
                                             NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'S',NULL,0,C_RELAT_AGRUP.CDSERVFILI, V_CDFILIAPUR);

                     GERA_NFRELACCDRS(P_CDFILIAL, V_NRLANCTONF, C_EFETCDRS.NRAGRUEFET, C_RELAT_CDRS.NRAGRUPRAT,
                                      V_CDFILIAPUR, P_CDCLIENTE, P_DATAINI,P_DATAFIM, P_NRAPURACFAT, V_IDGERAREL);
                      V_IDGERAREL := 'N';
                  END IF;
               END LOOP;
               UPDATE RELAT_CDRS
               SET NRLANCTONF = V_NRLANCTONF
               WHERE (CDFILIAL    = V_CDFILIAPUR)       AND
                     (CDCLIENTE   = P_CDCLIENTE)          AND
                     ((DTCDRS BETWEEN P_DATAINI AND P_DATAFIM) OR
                      (DTINIAPLASER BETWEEN P_DATAINI AND P_DATAFIM)) AND
                     (NRAGRUPNF   = C_EFETCDRS.NRAGRUEFET)    AND
                     (NRAGRUPRAT  = C_RELAT_CDRS.NRAGRUPRAT) AND
                     (CDSERVFILI  = C_RELAT_AGRUP.CDSERVFILI);
            END LOOP;

            /* EFETUA O FECHAMENTO DA NOTA, GERACAO DE IMPOSTOS */
            IF (V_IDNOVANOTA = 'S') THEN
               GERA_NOTAFISCAL_FECHAMENTO(P_CDFILIAL, V_NRLANCTONF);

               IF (V_DESCDOTACAO = '2') AND (V_VRCREDIDEBI <> 0) THEN
                  INSERT INTO AJCTRECEBER
                  (CDFILIAL,    NRLANCTONF,  DTAJUSTEREC, CDAJUCTREC,
                   DSAJUSTEREC, VRAJUSTEREC, NRSEQVENREC, NRPARCELAREC)
                  (SELECT MAX(CDFILIAL),  MAX(NRLANCTONF), SYSDATE , V_CDAJUSTPADR,
                          V_DSAJUCTREC,   V_VRCREDIDEBI,    MAX(NRSEQVENREC), MAX(NRPARCELAREC)
                   FROM CONTARECEBER
                   WHERE (CDFILIAL    =  P_CDFILIAL)    AND
                         (NRLANCTONF  =  V_NRLANCTONF));
               END IF;

            END IF;

            /* ISTO CONFIRMA A ULTIMA NOTA GERADA */
            COMMIT;

         END LOOP;

      END LOOP;

      /*GRAVA OS RATEIOS QUE NAO POSSUEM REFERENCIA NO SERVICO*/

      FOR C_EFETGRUPO IN(
               SELECT DISTINCT(NRAGREFRAT) AS NRAGREFRAT
               FROM
                 EFETRATCDRS
               WHERE
                  (CDFILIAL   = V_CDFILIAPUR)                     AND
                  (CDCLIENTE  = P_CDCLIENTE)                      AND
                  (DTRATCDRS BETWEEN P_DATAINI AND P_DATAFIM)     AND
                  (NOT EXISTS (SELECT NRAGRUEFET FROM EFETCDRS
                               WHERE (EFETCDRS.CDFILIAL   = EFETRATCDRS.CDFILIAL)  AND
                                     (EFETCDRS.CDCLIENTE  = EFETRATCDRS.CDCLIENTE) AND
                                     (DTEFETCDRS BETWEEN P_DATAINI AND P_DATAFIM)  AND
                                     (EFETCDRS.NRAGRUEFET = EFETRATCDRS.NRAGREFRAT)))
               ORDER BY NRAGREFRAT) LOOP

         FOR C_EFETRATDIA IN(
                 SELECT MAX(CDFILIAL) AS CDFILIAL, CDSERVFILI, MAX(CDCLIENTE) AS CDCLIENTE,
                        VRPRECRATE AS VRPRECUNIT, MAX(CDPRODUTO) AS CDPRODUTO, DTRATCDRS, NRAGREFRAT, SUM(QTDERATEIO) AS QTDERATEIO
                 FROM
                   EFETRATCDRS
                 WHERE
                    (CDFILIAL   = V_CDFILIAPUR)                     AND
                    (CDCLIENTE  = P_CDCLIENTE)                      AND
                    (DTRATCDRS BETWEEN P_DATAINI AND P_DATAFIM)     AND
                    (EFETRATCDRS.NRAGREFRAT = C_EFETGRUPO.NRAGREFRAT)
                 GROUP BY CDSERVFILI, NRAGREFRAT, DTRATCDRS, VRPRECRATE) LOOP

            IF TO_NUMBER(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD')) <= 15 THEN
               V_NRQUINZENA := 1;
               P_DATA := TO_DATE('01/'||TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'MM')||'/'||TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'YYYY'),'DD/MM/YYYY');
            ELSE
               V_NRQUINZENA := 2;
               P_DATA := TO_DATE('16/'||TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'MM')||'/'||TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'YYYY'),'DD/MM/YYYY');
            END IF;

            SELECT MAX(NRAGRUPNF), MAX(NRCDRS)
            INTO V_NRAGRUPNF, V_NUMECDRS
            FROM RELAT_CDRS
            WHERE CDFILIAL = C_EFETRATDIA.CDFILIAL      AND
                  CDCLIENTE = C_EFETRATDIA.CDCLIENTE    AND
                  CDSERVFILI= C_EFETRATDIA.CDSERVFILI   AND
                  DTINIAPLASER BETWEEN P_DATAINI AND P_DATAFIM AND
                  DTCDRS =  P_DATA                      AND
                  NRQUINZENA = V_NRQUINZENA             AND
                  NRAGRUPNF  = C_EFETRATDIA.NRAGREFRAT  AND
                  NRAGRUPRAT  = C_EFETRATDIA.NRAGREFRAT;

            SELECT COUNT(*)
            INTO V_CONT
            FROM RELAT_CDRS
            WHERE CDFILIAL = C_EFETRATDIA.CDFILIAL       AND
                  CDCLIENTE = C_EFETRATDIA.CDCLIENTE     AND
                  DTINIAPLASER BETWEEN P_DATAINI AND P_DATAFIM AND
                  DTCDRS =  P_DATA                      AND
                  NRQUINZENA = V_NRQUINZENA              AND
                  NRAGRUPNF  = C_EFETRATDIA.NRAGREFRAT   AND
                  NRAGRUPRAT  = C_EFETRATDIA.NRAGREFRAT;

            IF NOT V_NRAGRUPNF IS NULL THEN
               IF V_CONT = 13 THEN

                  NUMERO_CDRS('NUMECDRS'||C_EFETRATDIA.CDFILIAL||C_EFETRATDIA.CDCLIENTE,V_NUMECDRS);

                  SELECT COUNT(*)
                  INTO V_EXISTE
                  FROM RELAT_CDRS
                  WHERE CDFILIAL = C_EFETRATDIA.CDFILIAL     AND
                        CDCLIENTE = C_EFETRATDIA.CDCLIENTE   AND
                        NRCDRS = V_NUMECDRS;

                  IF V_EXISTE > 0 THEN
                     WHILE V_EXISTE > 0 LOOP
                        V_NUMECDRS := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_NUMECDRS) + 1)),10,'0');

                        SELECT COUNT(*)
                        INTO V_EXISTE
                        FROM RELAT_CDRS
                        WHERE CDFILIAL = C_EFETRATDIA.CDFILIAL     AND
                              CDCLIENTE = C_EFETRATDIA.CDCLIENTE   AND
                              NRCDRS = V_NUMECDRS;
                     END LOOP;

                     UPDATE NOVOCODIGO
                     SET NRSEQUENCIAL = V_NUMECDRS
                     WHERE CDCONTADOR = 'NUMECDRS'||C_EFETRATDIA.CDFILIAL||C_EFETRATDIA.CDCLIENTE;

                  END IF;

                  INSERT INTO RELAT_CDRS
                  (CDFILIAL, NRCDRS, CDCLIENTE,
                   CDSERVFILI, DTCDRS, NRQUINZENA,
                   QTEFETIVOS01,QTEFETIVOS02,QTEFETIVOS03,QTEFETIVOS04,QTEFETIVOS05,QTEFETIVOS06,QTEFETIVOS07,
                   QTEFETIVOS08,QTEFETIVOS09,QTEFETIVOS10, QTEFETIVOS11, QTEFETIVOS12, QTEFETIVOS13,QTEFETIVOS14,
                   QTEFETIVOS15,QTEFETIVOS16,NRAGRUPRAT,NRAGRUPNF,NRAPURACFAT, VRPRECUNIT, CDPRODUTO, DTINIAPLASER,
                   VRPRECUNIT01,VRPRECUNIT02,VRPRECUNIT03,VRPRECUNIT04,VRPRECUNIT05,VRPRECUNIT06,VRPRECUNIT07,
                   VRPRECUNIT08,VRPRECUNIT09,VRPRECUNIT10, VRPRECUNIT11, VRPRECUNIT12, VRPRECUNIT13,VRPRECUNIT14,
                   VRPRECUNIT15,VRPRECUNIT16)
                  VALUES (C_EFETRATDIA.CDFILIAL, V_NUMECDRS, C_EFETRATDIA.CDCLIENTE,
                          C_EFETRATDIA.CDSERVFILI, P_DATA, V_NRQUINZENA,
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '01',C_EFETRATDIA.QTDERATEIO, '16',C_EFETRATDIA.QTDERATEIO, 0),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '02',C_EFETRATDIA.QTDERATEIO, '17',C_EFETRATDIA.QTDERATEIO, 0),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '03',C_EFETRATDIA.QTDERATEIO, '18',C_EFETRATDIA.QTDERATEIO, 0),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '04',C_EFETRATDIA.QTDERATEIO, '19',C_EFETRATDIA.QTDERATEIO, 0),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '05',C_EFETRATDIA.QTDERATEIO, '20',C_EFETRATDIA.QTDERATEIO, 0),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '06',C_EFETRATDIA.QTDERATEIO, '21',C_EFETRATDIA.QTDERATEIO, 0),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '07',C_EFETRATDIA.QTDERATEIO, '22',C_EFETRATDIA.QTDERATEIO, 0),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '08',C_EFETRATDIA.QTDERATEIO, '23',C_EFETRATDIA.QTDERATEIO, 0),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '09',C_EFETRATDIA.QTDERATEIO, '24',C_EFETRATDIA.QTDERATEIO, 0),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '10',C_EFETRATDIA.QTDERATEIO, '25',C_EFETRATDIA.QTDERATEIO, 0),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '11',C_EFETRATDIA.QTDERATEIO, '26',C_EFETRATDIA.QTDERATEIO, 0),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '12',C_EFETRATDIA.QTDERATEIO, '27',C_EFETRATDIA.QTDERATEIO, 0),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '13',C_EFETRATDIA.QTDERATEIO, '28',C_EFETRATDIA.QTDERATEIO, 0),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '14',C_EFETRATDIA.QTDERATEIO, '29',C_EFETRATDIA.QTDERATEIO, 0),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '15',C_EFETRATDIA.QTDERATEIO, '30',C_EFETRATDIA.QTDERATEIO, 0),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '31',C_EFETRATDIA.QTDERATEIO, 0),
                          C_EFETRATDIA.NRAGREFRAT,C_EFETRATDIA.NRAGREFRAT,P_NRAPURACFAT,C_EFETRATDIA.VRPRECUNIT,C_EFETRATDIA.CDPRODUTO, P_DATAINI,
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '01',C_EFETRATDIA.VRPRECUNIT, '16',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '02',C_EFETRATDIA.VRPRECUNIT, '17',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '03',C_EFETRATDIA.VRPRECUNIT, '18',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '04',C_EFETRATDIA.VRPRECUNIT, '19',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '05',C_EFETRATDIA.VRPRECUNIT, '20',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '06',C_EFETRATDIA.VRPRECUNIT, '21',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '07',C_EFETRATDIA.VRPRECUNIT, '22',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '08',C_EFETRATDIA.VRPRECUNIT, '23',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '09',C_EFETRATDIA.VRPRECUNIT, '24',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '10',C_EFETRATDIA.VRPRECUNIT, '25',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '11',C_EFETRATDIA.VRPRECUNIT, '26',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '12',C_EFETRATDIA.VRPRECUNIT, '27',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '13',C_EFETRATDIA.VRPRECUNIT, '28',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '14',C_EFETRATDIA.VRPRECUNIT, '29',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '15',C_EFETRATDIA.VRPRECUNIT, '30',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                          DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '31',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT));

               ELSE
                  UPDATE RELAT_CDRS
                  SET QTEFETIVOS01 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '01',C_EFETRATDIA.QTDERATEIO, '16',C_EFETRATDIA.QTDERATEIO, QTEFETIVOS01),
                      QTEFETIVOS02 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '02',C_EFETRATDIA.QTDERATEIO, '17',C_EFETRATDIA.QTDERATEIO, QTEFETIVOS02),
                      QTEFETIVOS03 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '03',C_EFETRATDIA.QTDERATEIO, '18',C_EFETRATDIA.QTDERATEIO, QTEFETIVOS03),
                      QTEFETIVOS04 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '04',C_EFETRATDIA.QTDERATEIO, '19',C_EFETRATDIA.QTDERATEIO, QTEFETIVOS04),
                      QTEFETIVOS05 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '05',C_EFETRATDIA.QTDERATEIO, '20',C_EFETRATDIA.QTDERATEIO, QTEFETIVOS05),
                      QTEFETIVOS06 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '06',C_EFETRATDIA.QTDERATEIO, '21',C_EFETRATDIA.QTDERATEIO, QTEFETIVOS06),
                      QTEFETIVOS07 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '07',C_EFETRATDIA.QTDERATEIO, '22',C_EFETRATDIA.QTDERATEIO, QTEFETIVOS07),
                      QTEFETIVOS08 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '08',C_EFETRATDIA.QTDERATEIO, '23',C_EFETRATDIA.QTDERATEIO, QTEFETIVOS08),
                      QTEFETIVOS09 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '09',C_EFETRATDIA.QTDERATEIO, '24',C_EFETRATDIA.QTDERATEIO, QTEFETIVOS09),
                      QTEFETIVOS10 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '10',C_EFETRATDIA.QTDERATEIO, '25',C_EFETRATDIA.QTDERATEIO, QTEFETIVOS10),
                      QTEFETIVOS11 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '11',C_EFETRATDIA.QTDERATEIO, '26',C_EFETRATDIA.QTDERATEIO, QTEFETIVOS11),
                      QTEFETIVOS12 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '12',C_EFETRATDIA.QTDERATEIO, '27',C_EFETRATDIA.QTDERATEIO, QTEFETIVOS12),
                      QTEFETIVOS13 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '13',C_EFETRATDIA.QTDERATEIO, '28',C_EFETRATDIA.QTDERATEIO, QTEFETIVOS13),
                      QTEFETIVOS14 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '14',C_EFETRATDIA.QTDERATEIO, '29',C_EFETRATDIA.QTDERATEIO, QTEFETIVOS14),
                      QTEFETIVOS15 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '15',C_EFETRATDIA.QTDERATEIO, '30',C_EFETRATDIA.QTDERATEIO, QTEFETIVOS15),
                      QTEFETIVOS16 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '31',C_EFETRATDIA.QTDERATEIO, QTEFETIVOS16),

                      VRPRECUNIT01 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '01',C_EFETRATDIA.VRPRECUNIT, '16',C_EFETRATDIA.VRPRECUNIT, VRPRECUNIT01),
                      VRPRECUNIT02 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '02',C_EFETRATDIA.VRPRECUNIT, '17',C_EFETRATDIA.VRPRECUNIT, VRPRECUNIT02),
                      VRPRECUNIT03 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '03',C_EFETRATDIA.VRPRECUNIT, '18',C_EFETRATDIA.VRPRECUNIT, VRPRECUNIT03),
                      VRPRECUNIT04 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '04',C_EFETRATDIA.VRPRECUNIT, '19',C_EFETRATDIA.VRPRECUNIT, VRPRECUNIT04),
                      VRPRECUNIT05 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '05',C_EFETRATDIA.VRPRECUNIT, '20',C_EFETRATDIA.VRPRECUNIT, VRPRECUNIT05),
                      VRPRECUNIT06 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '06',C_EFETRATDIA.VRPRECUNIT, '21',C_EFETRATDIA.VRPRECUNIT, VRPRECUNIT06),
                      VRPRECUNIT07 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '07',C_EFETRATDIA.VRPRECUNIT, '22',C_EFETRATDIA.VRPRECUNIT, VRPRECUNIT07),
                      VRPRECUNIT08 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '08',C_EFETRATDIA.VRPRECUNIT, '23',C_EFETRATDIA.VRPRECUNIT, VRPRECUNIT08),
                      VRPRECUNIT09 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '09',C_EFETRATDIA.VRPRECUNIT, '24',C_EFETRATDIA.VRPRECUNIT, VRPRECUNIT09),
                      VRPRECUNIT10 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '10',C_EFETRATDIA.VRPRECUNIT, '25',C_EFETRATDIA.VRPRECUNIT, VRPRECUNIT10),
                      VRPRECUNIT11 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '11',C_EFETRATDIA.VRPRECUNIT, '26',C_EFETRATDIA.VRPRECUNIT, VRPRECUNIT11),
                      VRPRECUNIT12 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '12',C_EFETRATDIA.VRPRECUNIT, '27',C_EFETRATDIA.VRPRECUNIT, VRPRECUNIT12),
                      VRPRECUNIT13 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '13',C_EFETRATDIA.VRPRECUNIT, '28',C_EFETRATDIA.VRPRECUNIT, VRPRECUNIT13),
                      VRPRECUNIT14 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '14',C_EFETRATDIA.VRPRECUNIT, '29',C_EFETRATDIA.VRPRECUNIT, VRPRECUNIT14),
                      VRPRECUNIT15 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '15',C_EFETRATDIA.VRPRECUNIT, '30',C_EFETRATDIA.VRPRECUNIT, VRPRECUNIT15),
                      VRPRECUNIT16 = DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '31',C_EFETRATDIA.VRPRECUNIT, VRPRECUNIT16)
                  WHERE CDFILIAL   = C_EFETRATDIA.CDFILIAL     AND
                        CDCLIENTE  = C_EFETRATDIA.CDCLIENTE    AND
                        CDSERVFILI = C_EFETRATDIA.CDSERVFILI   AND
                        NRCDRS     = V_NUMECDRS                 AND
                        DTINIAPLASER BETWEEN P_DATAINI AND P_DATAFIM AND
                        DTCDRS     = P_DATA;
               END IF;
            ELSE

               SELECT MAX(NRAGRUPNF), MAX(NRCDRS)
               INTO V_NRAGRUPNF, V_NUMECDRS
               FROM RELAT_CDRS
               WHERE CDFILIAL   = C_EFETRATDIA.CDFILIAL    AND
                     CDCLIENTE  = C_EFETRATDIA.CDCLIENTE   AND
                     DTINIAPLASER BETWEEN P_DATAINI AND P_DATAFIM AND
                     DTCDRS =  P_DATA                      AND
                     NRQUINZENA = V_NRQUINZENA             AND
                     NRAGRUPNF  = C_EFETRATDIA.NRAGREFRAT  AND
                     NRAGRUPRAT = C_EFETRATDIA.NRAGREFRAT;

               IF (V_NRAGRUPNF IS NULL) OR (V_CONT = 13) THEN
                  NUMERO_CDRS('NUMECDRS'||C_EFETRATDIA.CDFILIAL||C_EFETRATDIA.CDCLIENTE,V_NUMECDRS);

                  SELECT COUNT(*)
                  INTO V_EXISTE
                  FROM RELAT_CDRS
                  WHERE CDFILIAL = C_EFETRATDIA.CDFILIAL     AND
                        CDCLIENTE = C_EFETRATDIA.CDCLIENTE   AND
                        NRCDRS = V_NUMECDRS;

                  IF V_EXISTE > 0 THEN
                     WHILE V_EXISTE > 0 LOOP
                        V_NUMECDRS := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_NUMECDRS) + 1)),10,'0');

                        SELECT COUNT(*)
                        INTO V_EXISTE
                        FROM RELAT_CDRS
                        WHERE CDFILIAL = C_EFETRATDIA.CDFILIAL     AND
                              CDCLIENTE = C_EFETRATDIA.CDCLIENTE   AND
                              NRCDRS = V_NUMECDRS;
                     END LOOP;

                     UPDATE NOVOCODIGO
                     SET NRSEQUENCIAL = V_NUMECDRS
                     WHERE CDCONTADOR = 'NUMECDRS'||C_EFETRATDIA.CDFILIAL||C_EFETRATDIA.CDCLIENTE;

                  END IF;

               END IF;

               INSERT INTO RELAT_CDRS
               (CDFILIAL, NRCDRS, CDCLIENTE,
                CDSERVFILI, DTCDRS, NRQUINZENA,
                QTEFETIVOS01,QTEFETIVOS02,QTEFETIVOS03,QTEFETIVOS04,QTEFETIVOS05,QTEFETIVOS06,QTEFETIVOS07,
                QTEFETIVOS08,QTEFETIVOS09,QTEFETIVOS10, QTEFETIVOS11, QTEFETIVOS12, QTEFETIVOS13,QTEFETIVOS14,
                QTEFETIVOS15,QTEFETIVOS16,NRAGRUPRAT,NRAGRUPNF,NRAPURACFAT,VRPRECUNIT,CDPRODUTO, DTINIAPLASER,
                VRPRECUNIT01,VRPRECUNIT02,VRPRECUNIT03,VRPRECUNIT04,VRPRECUNIT05,VRPRECUNIT06,VRPRECUNIT07,
                VRPRECUNIT08,VRPRECUNIT09,VRPRECUNIT10, VRPRECUNIT11, VRPRECUNIT12, VRPRECUNIT13,VRPRECUNIT14,
                VRPRECUNIT15,VRPRECUNIT16)
               VALUES (C_EFETRATDIA.CDFILIAL, V_NUMECDRS, C_EFETRATDIA.CDCLIENTE,
                       C_EFETRATDIA.CDSERVFILI, P_DATA, V_NRQUINZENA,
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '01',C_EFETRATDIA.QTDERATEIO, '16',C_EFETRATDIA.QTDERATEIO, 0),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '02',C_EFETRATDIA.QTDERATEIO, '17',C_EFETRATDIA.QTDERATEIO, 0),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '03',C_EFETRATDIA.QTDERATEIO, '18',C_EFETRATDIA.QTDERATEIO, 0),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '04',C_EFETRATDIA.QTDERATEIO, '19',C_EFETRATDIA.QTDERATEIO, 0),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '05',C_EFETRATDIA.QTDERATEIO, '20',C_EFETRATDIA.QTDERATEIO, 0),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '06',C_EFETRATDIA.QTDERATEIO, '21',C_EFETRATDIA.QTDERATEIO, 0),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '07',C_EFETRATDIA.QTDERATEIO, '22',C_EFETRATDIA.QTDERATEIO, 0),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '08',C_EFETRATDIA.QTDERATEIO, '23',C_EFETRATDIA.QTDERATEIO, 0),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '09',C_EFETRATDIA.QTDERATEIO, '24',C_EFETRATDIA.QTDERATEIO, 0),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '10',C_EFETRATDIA.QTDERATEIO, '25',C_EFETRATDIA.QTDERATEIO, 0),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '11',C_EFETRATDIA.QTDERATEIO, '26',C_EFETRATDIA.QTDERATEIO, 0),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '12',C_EFETRATDIA.QTDERATEIO, '27',C_EFETRATDIA.QTDERATEIO, 0),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '13',C_EFETRATDIA.QTDERATEIO, '28',C_EFETRATDIA.QTDERATEIO, 0),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '14',C_EFETRATDIA.QTDERATEIO, '29',C_EFETRATDIA.QTDERATEIO, 0),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '15',C_EFETRATDIA.QTDERATEIO, '30',C_EFETRATDIA.QTDERATEIO, 0),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '31',C_EFETRATDIA.QTDERATEIO, 0),
                       C_EFETRATDIA.NRAGREFRAT,C_EFETRATDIA.NRAGREFRAT,P_NRAPURACFAT,C_EFETRATDIA.VRPRECUNIT,C_EFETRATDIA.CDPRODUTO, P_DATAINI,
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '01',C_EFETRATDIA.VRPRECUNIT, '16',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '02',C_EFETRATDIA.VRPRECUNIT, '17',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '03',C_EFETRATDIA.VRPRECUNIT, '18',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '04',C_EFETRATDIA.VRPRECUNIT, '19',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '05',C_EFETRATDIA.VRPRECUNIT, '20',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '06',C_EFETRATDIA.VRPRECUNIT, '21',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '07',C_EFETRATDIA.VRPRECUNIT, '22',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '08',C_EFETRATDIA.VRPRECUNIT, '23',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '09',C_EFETRATDIA.VRPRECUNIT, '24',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '10',C_EFETRATDIA.VRPRECUNIT, '25',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '11',C_EFETRATDIA.VRPRECUNIT, '26',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '12',C_EFETRATDIA.VRPRECUNIT, '27',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '13',C_EFETRATDIA.VRPRECUNIT, '28',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '14',C_EFETRATDIA.VRPRECUNIT, '29',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '15',C_EFETRATDIA.VRPRECUNIT, '30',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT),
                       DECODE(TO_CHAR(C_EFETRATDIA.DTRATCDRS, 'DD'), '31',C_EFETRATDIA.VRPRECUNIT, C_EFETRATDIA.VRPRECUNIT));

            END IF;

         END LOOP;

         FOR C_RELAT_CDRS IN (SELECT DISTINCT(R.NRAGRUPRAT) AS NRAGRUPRAT
                              FROM RELAT_CDRS R
                              WHERE (R.CDFILIAL    = V_CDFILIAPUR)  AND
                                    (R.CDCLIENTE   = P_CDCLIENTE)          AND
                                    ((R.DTCDRS BETWEEN P_DATAINI AND P_DATAFIM) OR
                                     (R.DTINIAPLASER BETWEEN P_DATAINI AND P_DATAFIM)) AND
                                    (R.NRAGRUPNF   = C_EFETGRUPO.NRAGREFRAT)) LOOP

            V_IDNOVANOTA := 'N';
            V_CONTITEM   := V_TTITENSNF;

            FOR C_RELAT_AGRUP IN (SELECT MAX(R.CDFILIAL) AS CDFILIAL, MAX(R.CDCLIENTE) AS CDCLIENTE, MAX(P.NMPRODUTO) AS NMPRODUTO,
                                  R.CDSERVFILI, MAX(R.CDPRODUTO) AS CDPRODUTO,
                                  NVL(SUM(R.QTEFETIVOS01),0) AS QTEFETIVOS01, NVL(SUM(R.QTEFETIVOS02),0) AS QTEFETIVOS02, NVL(SUM(R.QTEFETIVOS03),0) AS QTEFETIVOS03,
                                  NVL(SUM(R.QTEFETIVOS04),0) AS QTEFETIVOS04, NVL(SUM(R.QTEFETIVOS05),0) AS QTEFETIVOS05, NVL(SUM(R.QTEFETIVOS06),0) AS QTEFETIVOS06,
                                  NVL(SUM(R.QTEFETIVOS07),0) AS QTEFETIVOS07, NVL(SUM(R.QTEFETIVOS08),0) AS QTEFETIVOS08, NVL(SUM(R.QTEFETIVOS09),0) AS QTEFETIVOS09,
                                  NVL(SUM(R.QTEFETIVOS10),0) AS QTEFETIVOS10, NVL(SUM(R.QTEFETIVOS11),0) AS QTEFETIVOS11, NVL(SUM(R.QTEFETIVOS12),0) AS QTEFETIVOS12,
                                  NVL(SUM(R.QTEFETIVOS13),0) AS QTEFETIVOS13, NVL(SUM(R.QTEFETIVOS14),0) AS QTEFETIVOS14, NVL(SUM(R.QTEFETIVOS15),0) AS QTEFETIVOS15,
                                  NVL(SUM(R.QTEFETIVOS16),0) AS QTEFETIVOS16,
                                  VRPRECUNIT01,VRPRECUNIT02,VRPRECUNIT03,VRPRECUNIT04,VRPRECUNIT05,VRPRECUNIT06,VRPRECUNIT07,
                                  VRPRECUNIT08,VRPRECUNIT09,VRPRECUNIT10, VRPRECUNIT11, VRPRECUNIT12, VRPRECUNIT13,VRPRECUNIT14,
                                  VRPRECUNIT15,VRPRECUNIT16
                           FROM RELAT_CDRS R, PRODUTO P
                           WHERE (R.CDFILIAL    = V_CDFILIAPUR)             AND
                                 (R.CDCLIENTE   = P_CDCLIENTE)              AND
                                 ((R.DTCDRS BETWEEN P_DATAINI AND P_DATAFIM) OR
                                  (R.DTINIAPLASER BETWEEN P_DATAINI AND P_DATAFIM)) AND
                                 (R.NRAGRUPNF   = C_EFETGRUPO.NRAGREFRAT)   AND
                                 (R.NRAGRUPRAT  = C_RELAT_CDRS.NRAGRUPRAT)  AND
                                 (R.CDPRODUTO  = P.CDPRODUTO)
                           GROUP BY R.CDSERVFILI,VRPRECUNIT01,VRPRECUNIT02,VRPRECUNIT03,VRPRECUNIT04,VRPRECUNIT05,VRPRECUNIT06,VRPRECUNIT07,
                                  VRPRECUNIT08,VRPRECUNIT09,VRPRECUNIT10, VRPRECUNIT11, VRPRECUNIT12, VRPRECUNIT13,VRPRECUNIT14,
                                  VRPRECUNIT15,VRPRECUNIT16
                           ORDER BY CDSERVFILI, CDPRODUTO) LOOP


               FOR C_RELAT_PRECO IN (SELECT DISTINCT VRPRECEFET
                                     FROM EFETCDRS
                                     WHERE (CDFILIAL = V_CDFILIAPUR)   AND
                                           (CDCLIENTE   = P_CDCLIENTE) AND
                                           (DTEFETCDRS BETWEEN P_DATAINI AND P_DATAFIM) AND
                                           (CDSERVFILI = C_RELAT_AGRUP.CDSERVFILI))LOOP


                  V_SOMAQT := 0;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT01 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS01;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT02   THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS02;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT03 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS03;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT04 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS04;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT05 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS05;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT06 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS06;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT07 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS07;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT08 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS08;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT09 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS09;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT10 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS10;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT11 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS11;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT12 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS12;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT13 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS13;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT14 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS14;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT15 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS15;
                  END IF;

                  IF C_RELAT_PRECO.VRPRECEFET = C_RELAT_AGRUP.VRPRECUNIT16 THEN
                     V_SOMAQT := V_SOMAQT + C_RELAT_AGRUP.QTEFETIVOS16;
                  END IF;


                  IF V_SOMAQT <> 0 THEN
                     IF (V_CONTITEM = V_TTITENSNF) THEN
                        /* EFETUA O FECHAMENTO DA NOTA, GERACAO DE IMPOSTOS */
                        IF (V_IDNOVANOTA = 'S') THEN
                           GERA_NOTAFISCAL_FECHAMENTO(P_CDFILIAL, V_NRLANCTONF);
                        END IF;

                        V_IDNOVANOTA := 'S';
                        V_CONTITEM   := 0;

                        NOVO_CODIGO('LANCNF/FILIAL' || P_CDFILIAL,V_NRLANCTONF);
                        V_NRLANCTONF := SUBSTR(V_NRLANCTONF,11,10);

                        V_NRSEQITPROD := '0000';
                        V_IDGERAREL := 'S';

                        GERA_NOTAFISCAL_CORPO (P_CDFILIAL,    V_CDFILIAPUR, V_CDEMPRESA,
                                               '01',          V_CDSERIE,    P_CDCLIENTE,
                                               P_DATAFIM,     'FAI',        V_NRLANCTONF,
                                               V_PRXLANCESTQ, 'N',          P_NRAPURACFAT,
                                               V_NRLANCTONF);


                        IF (V_DESCDOTACAO = '1') AND (V_VRCREDIDEBI <> 0) AND (V_ENCARGO IS NOT NULL) THEN
                           GERA_NOTAFISCAL_ENCARGO(P_CDFILIAL, V_NRLANCTONF, V_ENCARGO, V_VRCREDIDEBI);
                        END IF;

                     END IF;

                     V_NRSEQITPROD := LPAD((TO_NUMBER(NVL(V_NRSEQITPROD,'0000')) + 1), 4, 0);
                     V_CONTITEM := V_CONTITEM + 1;

                     GERA_NOTAFISCAL_PRODUTO(P_CDFILIAL, V_NRLANCTONF, C_RELAT_AGRUP.CDPRODUTO,
                                             C_RELAT_AGRUP.CDPRODUTO, C_RELAT_AGRUP.NMPRODUTO,
                                             V_SOMAQT, C_RELAT_PRECO.VRPRECEFET,0,NULL,NULL,
                                             NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'S',NULL,0,C_RELAT_AGRUP.CDSERVFILI, V_CDFILIAPUR);

                     GERA_NFRELACCDRS(P_CDFILIAL, V_NRLANCTONF, C_EFETGRUPO.NRAGREFRAT, C_RELAT_CDRS.NRAGRUPRAT,
                                      V_CDFILIAPUR, P_CDCLIENTE, P_DATAINI,P_DATAFIM, P_NRAPURACFAT, V_IDGERAREL);
                     V_IDGERAREL := 'N';
                  END IF;
               END LOOP;
               UPDATE RELAT_CDRS
               SET NRLANCTONF = V_NRLANCTONF
               WHERE (CDFILIAL    = V_CDFILIAPUR)       AND
                     (CDCLIENTE   = P_CDCLIENTE)          AND
                     ((DTCDRS BETWEEN P_DATAINI AND P_DATAFIM) OR
                      (DTINIAPLASER BETWEEN P_DATAINI AND P_DATAFIM)) AND
                     (NRAGRUPNF   = C_EFETGRUPO.NRAGREFRAT)    AND
                     (NRAGRUPRAT  = C_RELAT_CDRS.NRAGRUPRAT) AND
                     (CDSERVFILI  = C_RELAT_AGRUP.CDSERVFILI);
            END LOOP;

            /* EFETUA O FECHAMENTO DA NOTA, GERACAO DE IMPOSTOS */
            IF (V_IDNOVANOTA = 'S') THEN
               GERA_NOTAFISCAL_FECHAMENTO(P_CDFILIAL, V_NRLANCTONF);

               IF (V_DESCDOTACAO = '2') AND (V_VRCREDIDEBI <> 0) THEN
                  INSERT INTO AJCTRECEBER
                  (CDFILIAL,    NRLANCTONF,  DTAJUSTEREC, CDAJUCTREC,
                   DSAJUSTEREC, VRAJUSTEREC, NRSEQVENREC, NRPARCELAREC)
                  (SELECT MAX(CDFILIAL),  MAX(NRLANCTONF), SYSDATE , V_CDAJUSTPADR,
                          V_DSAJUCTREC,   V_VRCREDIDEBI,    MAX(NRSEQVENREC), MAX(NRPARCELAREC)
                   FROM CONTARECEBER
                   WHERE (CDFILIAL    =  P_CDFILIAL)    AND
                         (NRLANCTONF  =  V_NRLANCTONF));
               END IF;

            END IF;

            /* ISTO CONFIRMA A ULTIMA NOTA GERADA */
            COMMIT;

         END LOOP;

      END LOOP;

      UPDATE EFETRATCDRS
      SET NRAGREFRAT = NULL
      WHERE CDFILIAL = V_CDFILIAPUR AND
            CDCLIENTE = P_CDCLIENTE AND
            DTRATCDRS BETWEEN P_DATAINI AND P_DATAFIM AND
            NRAGREFRAT = '000';

      UPDATE EFETCDRS
      SET NRAGRUEFET = NULL
      WHERE CDFILIAL = V_CDFILIAPUR AND
            CDCLIENTE = P_CDCLIENTE AND
            DTEFETCDRS BETWEEN P_DATAINI AND P_DATAFIM AND
            NRAGRUEFET = '000';

   END IF;
END;
/

-- EXECUTE APURAC_GESLASER('0003', '0000000002', '01/07/99', '10/07/99', 'M1', '0000000004');
-- RAISE_APPLICATION_ERROR(-20501, 'MENSAGEM', TRUE);



/*
-- VERSAO --
BEGIN ATUVEROBJ('APURAC_GESLASER','5.03.009'); END;
*/

